WINVER: int
WM_USER: int
PY_0U: int
OFN_READONLY: int
OFN_OVERWRITEPROMPT: int
OFN_HIDEREADONLY: int
OFN_NOCHANGEDIR: int
OFN_SHOWHELP: int
OFN_ENABLEHOOK: int
OFN_ENABLETEMPLATE: int
OFN_ENABLETEMPLATEHANDLE: int
OFN_NOVALIDATE: int
OFN_ALLOWMULTISELECT: int
OFN_EXTENSIONDIFFERENT: int
OFN_PATHMUSTEXIST: int
OFN_FILEMUSTEXIST: int
OFN_CREATEPROMPT: int
OFN_SHAREAWARE: int
OFN_NOREADONLYRETURN: int
OFN_NOTESTFILECREATE: int
OFN_NONETWORKBUTTON: int
OFN_NOLONGNAMES: int
OFN_EXPLORER: int
OFN_NODEREFERENCELINKS: int
OFN_LONGNAMES: int
OFN_ENABLEINCLUDENOTIFY: int
OFN_ENABLESIZING: int
OFN_DONTADDTORECENT: int
OFN_FORCESHOWHIDDEN: int
OFN_EX_NOPLACESBAR: int
OFN_SHAREFALLTHROUGH: int
OFN_SHARENOWARN: int
OFN_SHAREWARN: int
CDN_FIRST: int
CDN_LAST: int
CDN_INITDONE: int
CDN_SELCHANGE: int
CDN_FOLDERCHANGE: int
CDN_SHAREVIOLATION: int
CDN_HELP: int
CDN_FILEOK: int
CDN_TYPECHANGE: int
CDN_INCLUDEITEM: int
CDM_FIRST: int
CDM_LAST: int
CDM_GETSPEC: int
CDM_GETFILEPATH: int
CDM_GETFOLDERPATH: int
CDM_SETCONTROLTEXT: int
CDM_HIDECONTROL: int
CDM_SETDEFEXT: int
CC_RGBINIT: int
CC_FULLOPEN: int
CC_PREVENTFULLOPEN: int
CC_SHOWHELP: int
CC_ENABLEHOOK: int
CC_ENABLETEMPLATE: int
CC_ENABLETEMPLATEHANDLE: int
CC_SOLIDCOLOR: int
CC_ANYCOLOR: int
FR_DOWN: int
FR_WHOLEWORD: int
FR_MATCHCASE: int
FR_FINDNEXT: int
FR_REPLACE: int
FR_REPLACEALL: int
FR_DIALOGTERM: int
FR_SHOWHELP: int
FR_ENABLEHOOK: int
FR_ENABLETEMPLATE: int
FR_NOUPDOWN: int
FR_NOMATCHCASE: int
FR_NOWHOLEWORD: int
FR_ENABLETEMPLATEHANDLE: int
FR_HIDEUPDOWN: int
FR_HIDEMATCHCASE: int
FR_HIDEWHOLEWORD: int
CF_SCREENFONTS: int
CF_PRINTERFONTS: int
CF_BOTH: int
CF_SHOWHELP: int
CF_ENABLEHOOK: int
CF_ENABLETEMPLATE: int
CF_ENABLETEMPLATEHANDLE: int
CF_INITTOLOGFONTSTRUCT: int
CF_USESTYLE: int
CF_EFFECTS: int
CF_APPLY: int
CF_ANSIONLY: int
CF_SCRIPTSONLY: int
CF_NOVECTORFONTS: int
CF_NOOEMFONTS: int
CF_NOSIMULATIONS: int
CF_LIMITSIZE: int
CF_FIXEDPITCHONLY: int
CF_WYSIWYG: int
CF_FORCEFONTEXIST: int
CF_SCALABLEONLY: int
CF_TTONLY: int
CF_NOFACESEL: int
CF_NOSTYLESEL: int
CF_NOSIZESEL: int
CF_SELECTSCRIPT: int
CF_NOSCRIPTSEL: int
CF_NOVERTFONTS: int
SIMULATED_FONTTYPE: int
PRINTER_FONTTYPE: int
SCREEN_FONTTYPE: int
BOLD_FONTTYPE: int
ITALIC_FONTTYPE: int
REGULAR_FONTTYPE: int
OPENTYPE_FONTTYPE: int
TYPE1_FONTTYPE: int
DSIG_FONTTYPE: int
WM_CHOOSEFONT_GETLOGFONT: int
WM_CHOOSEFONT_SETLOGFONT: int
WM_CHOOSEFONT_SETFLAGS: int
LBSELCHSTRINGA: str
SHAREVISTRINGA: str
FILEOKSTRINGA: str
COLOROKSTRINGA: str
SETRGBSTRINGA: str
HELPMSGSTRINGA: str
FINDMSGSTRINGA: str
LBSELCHSTRING: str
SHAREVISTRING: str
FILEOKSTRING: str
COLOROKSTRING: str
SETRGBSTRING: str
HELPMSGSTRING: str
FINDMSGSTRING: str
CD_LBSELNOITEMS: int
CD_LBSELCHANGE: int
CD_LBSELSUB: int
CD_LBSELADD: int
PD_ALLPAGES: int
PD_SELECTION: int
PD_PAGENUMS: int
PD_NOSELECTION: int
PD_NOPAGENUMS: int
PD_COLLATE: int
PD_PRINTTOFILE: int
PD_PRINTSETUP: int
PD_NOWARNING: int
PD_RETURNDC: int
PD_RETURNIC: int
PD_RETURNDEFAULT: int
PD_SHOWHELP: int
PD_ENABLEPRINTHOOK: int
PD_ENABLESETUPHOOK: int
PD_ENABLEPRINTTEMPLATE: int
PD_ENABLESETUPTEMPLATE: int
PD_ENABLEPRINTTEMPLATEHANDLE: int
PD_ENABLESETUPTEMPLATEHANDLE: int
PD_USEDEVMODECOPIES: int
PD_DISABLEPRINTTOFILE: int
PD_HIDEPRINTTOFILE: int
PD_NONETWORKBUTTON: int
DN_DEFAULTPRN: int
WM_PSD_PAGESETUPDLG: int
WM_PSD_FULLPAGERECT: int
WM_PSD_MINMARGINRECT: int
WM_PSD_MARGINRECT: int
WM_PSD_GREEKTEXTRECT: int
WM_PSD_ENVSTAMPRECT: int
WM_PSD_YAFULLPAGERECT: int
PSD_DEFAULTMINMARGINS: int
PSD_INWININIINTLMEASURE: int
PSD_MINMARGINS: int
PSD_MARGINS: int
PSD_INTHOUSANDTHSOFINCHES: int
PSD_INHUNDREDTHSOFMILLIMETERS: int
PSD_DISABLEMARGINS: int
PSD_DISABLEPRINTER: int
PSD_NOWARNING: int
PSD_DISABLEORIENTATION: int
PSD_RETURNDEFAULT: int
PSD_DISABLEPAPER: int
PSD_SHOWHELP: int
PSD_ENABLEPAGESETUPHOOK: int
PSD_ENABLEPAGESETUPTEMPLATE: int
PSD_ENABLEPAGESETUPTEMPLATEHANDLE: int
PSD_ENABLEPAGEPAINTHOOK: int
PSD_DISABLEPAGEPAINTING: int
PSD_NONETWORKBUTTON: int
HKEY_CLASSES_ROOT: int
HKEY_CURRENT_USER: int
HKEY_LOCAL_MACHINE: int
HKEY_USERS: int
HKEY_PERFORMANCE_DATA: int
HKEY_CURRENT_CONFIG: int
HKEY_DYN_DATA: int
HKEY_PERFORMANCE_TEXT: int
HKEY_PERFORMANCE_NLSTEXT: int
HWND_BROADCAST: int
HWND_DESKTOP: int
HWND_TOP: int
HWND_BOTTOM: int
HWND_TOPMOST: int
HWND_NOTOPMOST: int
HWND_MESSAGE: int
SM_CXSCREEN: int
SM_CYSCREEN: int
SM_CXVSCROLL: int
SM_CYHSCROLL: int
SM_CYCAPTION: int
SM_CXBORDER: int
SM_CYBORDER: int
SM_CXDLGFRAME: int
SM_CYDLGFRAME: int
SM_CYVTHUMB: int
SM_CXHTHUMB: int
SM_CXICON: int
SM_CYICON: int
SM_CXCURSOR: int
SM_CYCURSOR: int
SM_CYMENU: int
SM_CXFULLSCREEN: int
SM_CYFULLSCREEN: int
SM_CYKANJIWINDOW: int
SM_MOUSEPRESENT: int
SM_CYVSCROLL: int
SM_CXHSCROLL: int
SM_DEBUG: int
SM_SWAPBUTTON: int
SM_RESERVED1: int
SM_RESERVED2: int
SM_RESERVED3: int
SM_RESERVED4: int
SM_CXMIN: int
SM_CYMIN: int
SM_CXSIZE: int
SM_CYSIZE: int
SM_CXFRAME: int
SM_CYFRAME: int
SM_CXMINTRACK: int
SM_CYMINTRACK: int
SM_CXDOUBLECLK: int
SM_CYDOUBLECLK: int
SM_CXICONSPACING: int
SM_CYICONSPACING: int
SM_MENUDROPALIGNMENT: int
SM_PENWINDOWS: int
SM_DBCSENABLED: int
SM_CMOUSEBUTTONS: int
SM_CXFIXEDFRAME: int
SM_CYFIXEDFRAME: int
SM_CXSIZEFRAME: int
SM_CYSIZEFRAME: int
SM_SECURE: int
SM_CXEDGE: int
SM_CYEDGE: int
SM_CXMINSPACING: int
SM_CYMINSPACING: int
SM_CXSMICON: int
SM_CYSMICON: int
SM_CYSMCAPTION: int
SM_CXSMSIZE: int
SM_CYSMSIZE: int
SM_CXMENUSIZE: int
SM_CYMENUSIZE: int
SM_ARRANGE: int
SM_CXMINIMIZED: int
SM_CYMINIMIZED: int
SM_CXMAXTRACK: int
SM_CYMAXTRACK: int
SM_CXMAXIMIZED: int
SM_CYMAXIMIZED: int
SM_NETWORK: int
SM_CLEANBOOT: int
SM_CXDRAG: int
SM_CYDRAG: int
SM_SHOWSOUNDS: int
SM_CXMENUCHECK: int
SM_CYMENUCHECK: int
SM_SLOWMACHINE: int
SM_MIDEASTENABLED: int
SM_MOUSEWHEELPRESENT: int
SM_XVIRTUALSCREEN: int
SM_YVIRTUALSCREEN: int
SM_CXVIRTUALSCREEN: int
SM_CYVIRTUALSCREEN: int
SM_CMONITORS: int
SM_SAMEDISPLAYFORMAT: int
SM_CMETRICS: int
MNC_IGNORE: int
MNC_CLOSE: int
MNC_EXECUTE: int
MNC_SELECT: int
MNS_NOCHECK: int
MNS_MODELESS: int
MNS_DRAGDROP: int
MNS_AUTODISMISS: int
MNS_NOTIFYBYPOS: int
MNS_CHECKORBMP: int
MIM_MAXHEIGHT: int
MIM_BACKGROUND: int
MIM_HELPID: int
MIM_MENUDATA: int
MIM_STYLE: int
MIM_APPLYTOSUBMENUS: int
MND_CONTINUE: int
MND_ENDMENU: int
MNGOF_GAP: int
MNGO_NOINTERFACE: int
MNGO_NOERROR: int
MIIM_STATE: int
MIIM_ID: int
MIIM_SUBMENU: int
MIIM_CHECKMARKS: int
MIIM_TYPE: int
MIIM_DATA: int
MIIM_STRING: int
MIIM_BITMAP: int
MIIM_FTYPE: int
HBMMENU_CALLBACK: int
HBMMENU_SYSTEM: int
HBMMENU_MBAR_RESTORE: int
HBMMENU_MBAR_MINIMIZE: int
HBMMENU_MBAR_CLOSE: int
HBMMENU_MBAR_CLOSE_D: int
HBMMENU_MBAR_MINIMIZE_D: int
HBMMENU_POPUP_CLOSE: int
HBMMENU_POPUP_RESTORE: int
HBMMENU_POPUP_MAXIMIZE: int
HBMMENU_POPUP_MINIMIZE: int
GMDI_USEDISABLED: int
GMDI_GOINTOPOPUPS: int
TPM_LEFTBUTTON: int
TPM_RIGHTBUTTON: int
TPM_LEFTALIGN: int
TPM_CENTERALIGN: int
TPM_RIGHTALIGN: int
TPM_TOPALIGN: int
TPM_VCENTERALIGN: int
TPM_BOTTOMALIGN: int
TPM_HORIZONTAL: int
TPM_VERTICAL: int
TPM_NONOTIFY: int
TPM_RETURNCMD: int
TPM_RECURSE: int
DOF_EXECUTABLE: int
DOF_DOCUMENT: int
DOF_DIRECTORY: int
DOF_MULTIPLE: int
DOF_PROGMAN: int
DOF_SHELLDATA: int
DO_DROPFILE: int
DO_PRINTFILE: int
DT_TOP: int
DT_LEFT: int
DT_CENTER: int
DT_RIGHT: int
DT_VCENTER: int
DT_BOTTOM: int
DT_WORDBREAK: int
DT_SINGLELINE: int
DT_EXPANDTABS: int
DT_TABSTOP: int
DT_NOCLIP: int
DT_EXTERNALLEADING: int
DT_CALCRECT: int
DT_NOPREFIX: int
DT_INTERNAL: int
DT_EDITCONTROL: int
DT_PATH_ELLIPSIS: int
DT_END_ELLIPSIS: int
DT_MODIFYSTRING: int
DT_RTLREADING: int
DT_WORD_ELLIPSIS: int
DST_COMPLEX: int
DST_TEXT: int
DST_PREFIXTEXT: int
DST_ICON: int
DST_BITMAP: int
DSS_NORMAL: int
DSS_UNION: int
DSS_DISABLED: int
DSS_MONO: int
DSS_RIGHT: int
DCX_WINDOW: int
DCX_CACHE: int
DCX_NORESETATTRS: int
DCX_CLIPCHILDREN: int
DCX_CLIPSIBLINGS: int
DCX_PARENTCLIP: int
DCX_EXCLUDERGN: int
DCX_INTERSECTRGN: int
DCX_EXCLUDEUPDATE: int
DCX_INTERSECTUPDATE: int
DCX_LOCKWINDOWUPDATE: int
DCX_VALIDATE: int
CUDR_NORMAL: int
CUDR_NOSNAPTOGRID: int
CUDR_NORESOLVEPOSITIONS: int
CUDR_NOCLOSEGAPS: int
CUDR_NEGATIVECOORDS: int
CUDR_NOPRIMARY: int
RDW_INVALIDATE: int
RDW_INTERNALPAINT: int
RDW_ERASE: int
RDW_VALIDATE: int
RDW_NOINTERNALPAINT: int
RDW_NOERASE: int
RDW_NOCHILDREN: int
RDW_ALLCHILDREN: int
RDW_UPDATENOW: int
RDW_ERASENOW: int
RDW_FRAME: int
RDW_NOFRAME: int
SW_SCROLLCHILDREN: int
SW_INVALIDATE: int
SW_ERASE: int
SW_SMOOTHSCROLL: int
ESB_ENABLE_BOTH: int
ESB_DISABLE_BOTH: int
ESB_DISABLE_LEFT: int
ESB_DISABLE_RIGHT: int
ESB_DISABLE_UP: int
ESB_DISABLE_DOWN: int
ESB_DISABLE_LTUP: int
ESB_DISABLE_RTDN: int
HELPINFO_WINDOW: int
HELPINFO_MENUITEM: int
MB_OK: int
MB_OKCANCEL: int
MB_ABORTRETRYIGNORE: int
MB_YESNOCANCEL: int
MB_YESNO: int
MB_RETRYCANCEL: int
MB_ICONHAND: int
MB_ICONQUESTION: int
MB_ICONEXCLAMATION: int
MB_ICONASTERISK: int
MB_ICONWARNING: int
MB_ICONERROR: int
MB_ICONINFORMATION: int
MB_ICONSTOP: int
MB_DEFBUTTON1: int
MB_DEFBUTTON2: int
MB_DEFBUTTON3: int
MB_DEFBUTTON4: int
MB_APPLMODAL: int
MB_SYSTEMMODAL: int
MB_TASKMODAL: int
MB_HELP: int
MB_NOFOCUS: int
MB_SETFOREGROUND: int
MB_DEFAULT_DESKTOP_ONLY: int
MB_TOPMOST: int
MB_RIGHT: int
MB_RTLREADING: int
MB_SERVICE_NOTIFICATION: int
MB_TYPEMASK: int
MB_USERICON: int
MB_ICONMASK: int
MB_DEFMASK: int
MB_MODEMASK: int
MB_MISCMASK: int
CWP_ALL: int
CWP_SKIPINVISIBLE: int
CWP_SKIPDISABLED: int
CWP_SKIPTRANSPARENT: int
CTLCOLOR_MSGBOX: int
CTLCOLOR_EDIT: int
CTLCOLOR_BTN: int
CTLCOLOR_DLG: int
CTLCOLOR_SCROLLBAR: int
CTLCOLOR_STATIC: int
CTLCOLOR_MAX: int
COLOR_SCROLLBAR: int
COLOR_BACKGROUND: int
COLOR_ACTIVECAPTION: int
COLOR_INACTIVECAPTION: int
COLOR_MENU: int
COLOR_WINDOW: int
COLOR_WINDOWFRAME: int
COLOR_MENUTEXT: int
COLOR_WINDOWTEXT: int
COLOR_CAPTIONTEXT: int
COLOR_ACTIVEBORDER: int
COLOR_INACTIVEBORDER: int
COLOR_APPWORKSPACE: int
COLOR_HIGHLIGHT: int
COLOR_HIGHLIGHTTEXT: int
COLOR_BTNFACE: int
COLOR_BTNSHADOW: int
COLOR_GRAYTEXT: int
COLOR_BTNTEXT: int
COLOR_INACTIVECAPTIONTEXT: int
COLOR_BTNHIGHLIGHT: int
COLOR_3DDKSHADOW: int
COLOR_3DLIGHT: int
COLOR_INFOTEXT: int
COLOR_INFOBK: int
COLOR_HOTLIGHT: int
COLOR_GRADIENTACTIVECAPTION: int
COLOR_GRADIENTINACTIVECAPTION: int
COLOR_DESKTOP: int
COLOR_3DFACE: int
COLOR_3DSHADOW: int
COLOR_3DHIGHLIGHT: int
COLOR_3DHILIGHT: int
COLOR_BTNHILIGHT: int
GW_HWNDFIRST: int
GW_HWNDLAST: int
GW_HWNDNEXT: int
GW_HWNDPREV: int
GW_OWNER: int
GW_CHILD: int
GW_ENABLEDPOPUP: int
GW_MAX: int
MF_INSERT: int
MF_CHANGE: int
MF_APPEND: int
MF_DELETE: int
MF_REMOVE: int
MF_BYCOMMAND: int
MF_BYPOSITION: int
MF_SEPARATOR: int
MF_ENABLED: int
MF_GRAYED: int
MF_DISABLED: int
MF_UNCHECKED: int
MF_CHECKED: int
MF_USECHECKBITMAPS: int
MF_STRING: int
MF_BITMAP: int
MF_OWNERDRAW: int
MF_POPUP: int
MF_MENUBARBREAK: int
MF_MENUBREAK: int
MF_UNHILITE: int
MF_HILITE: int
MF_DEFAULT: int
MF_SYSMENU: int
MF_HELP: int
MF_RIGHTJUSTIFY: int
MF_MOUSESELECT: int
MF_END: int
MFT_STRING: int
MFT_BITMAP: int
MFT_MENUBARBREAK: int
MFT_MENUBREAK: int
MFT_OWNERDRAW: int
MFT_RADIOCHECK: int
MFT_SEPARATOR: int
MFT_RIGHTORDER: int
MFT_RIGHTJUSTIFY: int
MFS_GRAYED: int
MFS_DISABLED: int
MFS_CHECKED: int
MFS_HILITE: int
MFS_ENABLED: int
MFS_UNCHECKED: int
MFS_UNHILITE: int
MFS_DEFAULT: int
MFS_MASK: int
MFS_HOTTRACKDRAWN: int
MFS_CACHEDBMP: int
MFS_BOTTOMGAPDROP: int
MFS_TOPGAPDROP: int
MFS_GAPDROP: int
SC_SIZE: int
SC_MOVE: int
SC_MINIMIZE: int
SC_MAXIMIZE: int
SC_NEXTWINDOW: int
SC_PREVWINDOW: int
SC_CLOSE: int
SC_VSCROLL: int
SC_HSCROLL: int
SC_MOUSEMENU: int
SC_KEYMENU: int
SC_ARRANGE: int
SC_RESTORE: int
SC_SCREENSAVE: int
SC_HOTKEY: int
SC_DEFAULT: int
SC_MONITORPOWER: int
SC_CONTEXTHELP: int
SC_SEPARATOR: int
SC_ICON: int
SC_ZOOM: int
IDC_ARROW: int
IDC_IBEAM: int
IDC_WAIT: int
IDC_CROSS: int
IDC_UPARROW: int
IDC_SIZE: int
IDC_ICON: int
IDC_SIZENWSE: int
IDC_SIZENESW: int
IDC_SIZEWE: int
IDC_SIZENS: int
IDC_SIZEALL: int
IDC_NO: int
IDC_HAND: int
IDC_APPSTARTING: int
IDC_HELP: int
IMAGE_BITMAP: int
IMAGE_ICON: int
IMAGE_CURSOR: int
IMAGE_ENHMETAFILE: int
LR_DEFAULTCOLOR: int
LR_MONOCHROME: int
LR_COLOR: int
LR_COPYRETURNORG: int
LR_COPYDELETEORG: int
LR_LOADFROMFILE: int
LR_LOADTRANSPARENT: int
LR_DEFAULTSIZE: int
LR_LOADREALSIZE: int
LR_LOADMAP3DCOLORS: int
LR_CREATEDIBSECTION: int
LR_COPYFROMRESOURCE: int
LR_SHARED: int
DI_MASK: int
DI_IMAGE: int
DI_NORMAL: int
DI_COMPAT: int
DI_DEFAULTSIZE: int
RES_ICON: int
RES_CURSOR: int
OBM_CLOSE: int
OBM_UPARROW: int
OBM_DNARROW: int
OBM_RGARROW: int
OBM_LFARROW: int
OBM_REDUCE: int
OBM_ZOOM: int
OBM_RESTORE: int
OBM_REDUCED: int
OBM_ZOOMD: int
OBM_RESTORED: int
OBM_UPARROWD: int
OBM_DNARROWD: int
OBM_RGARROWD: int
OBM_LFARROWD: int
OBM_MNARROW: int
OBM_COMBO: int
OBM_UPARROWI: int
OBM_DNARROWI: int
OBM_RGARROWI: int
OBM_LFARROWI: int
OBM_OLD_CLOSE: int
OBM_SIZE: int
OBM_OLD_UPARROW: int
OBM_OLD_DNARROW: int
OBM_OLD_RGARROW: int
OBM_OLD_LFARROW: int
OBM_BTSIZE: int
OBM_CHECK: int
OBM_CHECKBOXES: int
OBM_BTNCORNERS: int
OBM_OLD_REDUCE: int
OBM_OLD_ZOOM: int
OBM_OLD_RESTORE: int
OCR_NORMAL: int
OCR_IBEAM: int
OCR_WAIT: int
OCR_CROSS: int
OCR_UP: int
OCR_SIZE: int
OCR_ICON: int
OCR_SIZENWSE: int
OCR_SIZENESW: int
OCR_SIZEWE: int
OCR_SIZENS: int
OCR_SIZEALL: int
OCR_ICOCUR: int
OCR_NO: int
OCR_HAND: int
OCR_APPSTARTING: int
OIC_SAMPLE: int
OIC_HAND: int
OIC_QUES: int
OIC_BANG: int
OIC_NOTE: int
OIC_WINLOGO: int
OIC_WARNING: int
OIC_ERROR: int
OIC_INFORMATION: int
ORD_LANGDRIVER: int
IDI_APPLICATION: int
IDI_HAND: int
IDI_QUESTION: int
IDI_EXCLAMATION: int
IDI_ASTERISK: int
IDI_WINLOGO: int
IDI_WARNING: int
IDI_ERROR: int
IDI_INFORMATION: int
IDOK: int
IDCANCEL: int
IDABORT: int
IDRETRY: int
IDIGNORE: int
IDYES: int
IDNO: int
IDCLOSE: int
IDHELP: int
ES_LEFT: int
ES_CENTER: int
ES_RIGHT: int
ES_MULTILINE: int
ES_UPPERCASE: int
ES_LOWERCASE: int
ES_PASSWORD: int
ES_AUTOVSCROLL: int
ES_AUTOHSCROLL: int
ES_NOHIDESEL: int
ES_OEMCONVERT: int
ES_READONLY: int
ES_WANTRETURN: int
ES_NUMBER: int
EN_SETFOCUS: int
EN_KILLFOCUS: int
EN_CHANGE: int
EN_UPDATE: int
EN_ERRSPACE: int
EN_MAXTEXT: int
EN_HSCROLL: int
EN_VSCROLL: int
EC_LEFTMARGIN: int
EC_RIGHTMARGIN: int
EC_USEFONTINFO: int
EMSIS_COMPOSITIONSTRING: int
EIMES_GETCOMPSTRATONCE: int
EIMES_CANCELCOMPSTRINFOCUS: int
EIMES_COMPLETECOMPSTRKILLFOCUS: int
EM_GETSEL: int
EM_SETSEL: int
EM_GETRECT: int
EM_SETRECT: int
EM_SETRECTNP: int
EM_SCROLL: int
EM_LINESCROLL: int
EM_SCROLLCARET: int
EM_GETMODIFY: int
EM_SETMODIFY: int
EM_GETLINECOUNT: int
EM_LINEINDEX: int
EM_SETHANDLE: int
EM_GETHANDLE: int
EM_GETTHUMB: int
EM_LINELENGTH: int
EM_REPLACESEL: int
EM_GETLINE: int
EM_LIMITTEXT: int
EM_CANUNDO: int
EM_UNDO: int
EM_FMTLINES: int
EM_LINEFROMCHAR: int
EM_SETTABSTOPS: int
EM_SETPASSWORDCHAR: int
EM_EMPTYUNDOBUFFER: int
EM_GETFIRSTVISIBLELINE: int
EM_SETREADONLY: int
EM_SETWORDBREAKPROC: int
EM_GETWORDBREAKPROC: int
EM_GETPASSWORDCHAR: int
EM_SETMARGINS: int
EM_GETMARGINS: int
EM_SETLIMITTEXT: int
EM_GETLIMITTEXT: int
EM_POSFROMCHAR: int
EM_CHARFROMPOS: int
EM_SETIMESTATUS: int
EM_GETIMESTATUS: int
WB_LEFT: int
WB_RIGHT: int
WB_ISDELIMITER: int
BS_PUSHBUTTON: int
BS_DEFPUSHBUTTON: int
BS_CHECKBOX: int
BS_AUTOCHECKBOX: int
BS_RADIOBUTTON: int
BS_3STATE: int
BS_AUTO3STATE: int
BS_GROUPBOX: int
BS_USERBUTTON: int
BS_AUTORADIOBUTTON: int
BS_OWNERDRAW: int
BS_LEFTTEXT: int
BS_TEXT: int
BS_ICON: int
BS_BITMAP: int
BS_LEFT: int
BS_RIGHT: int
BS_CENTER: int
BS_TOP: int
BS_BOTTOM: int
BS_VCENTER: int
BS_PUSHLIKE: int
BS_MULTILINE: int
BS_NOTIFY: int
BS_FLAT: int
BS_RIGHTBUTTON: int
BN_CLICKED: int
BN_PAINT: int
BN_HILITE: int
BN_UNHILITE: int
BN_DISABLE: int
BN_DOUBLECLICKED: int
BN_PUSHED: int
BN_UNPUSHED: int
BN_DBLCLK: int
BN_SETFOCUS: int
BN_KILLFOCUS: int
BM_GETCHECK: int
BM_SETCHECK: int
BM_GETSTATE: int
BM_SETSTATE: int
BM_SETSTYLE: int
BM_CLICK: int
BM_GETIMAGE: int
BM_SETIMAGE: int
BST_UNCHECKED: int
BST_CHECKED: int
BST_INDETERMINATE: int
BST_PUSHED: int
BST_FOCUS: int
SS_LEFT: int
SS_CENTER: int
SS_RIGHT: int
SS_ICON: int
SS_BLACKRECT: int
SS_GRAYRECT: int
SS_WHITERECT: int
SS_BLACKFRAME: int
SS_GRAYFRAME: int
SS_WHITEFRAME: int
SS_USERITEM: int
SS_SIMPLE: int
SS_LEFTNOWORDWRAP: int
SS_BITMAP: int
SS_OWNERDRAW: int
SS_ENHMETAFILE: int
SS_ETCHEDHORZ: int
SS_ETCHEDVERT: int
SS_ETCHEDFRAME: int
SS_TYPEMASK: int
SS_NOPREFIX: int
SS_NOTIFY: int
SS_CENTERIMAGE: int
SS_RIGHTJUST: int
SS_REALSIZEIMAGE: int
SS_SUNKEN: int
SS_ENDELLIPSIS: int
SS_PATHELLIPSIS: int
SS_WORDELLIPSIS: int
SS_ELLIPSISMASK: int
STM_SETICON: int
STM_GETICON: int
STM_SETIMAGE: int
STM_GETIMAGE: int
STN_CLICKED: int
STN_DBLCLK: int
STN_ENABLE: int
STN_DISABLE: int
STM_MSGMAX: int
DWL_MSGRESULT: int
DWL_DLGPROC: int
DWL_USER: int
DDL_READWRITE: int
DDL_READONLY: int
DDL_HIDDEN: int
DDL_SYSTEM: int
DDL_DIRECTORY: int
DDL_ARCHIVE: int
DDL_POSTMSGS: int
DDL_DRIVES: int
DDL_EXCLUSIVE: int
RT_CURSOR: int
RT_BITMAP: int
RT_ICON: int
RT_MENU: int
RT_DIALOG: int
RT_STRING: int
RT_FONTDIR: int
RT_FONT: int
RT_ACCELERATOR: int
RT_RCDATA: int
RT_MESSAGETABLE: int
DIFFERENCE: int
RT_GROUP_CURSOR: int
RT_GROUP_ICON: int
RT_VERSION: int
RT_DLGINCLUDE: int
RT_PLUGPLAY: int
RT_VXD: int
RT_ANICURSOR: int
RT_ANIICON: int
RT_HTML: int
SB_HORZ: int
SB_VERT: int
SB_CTL: int
SB_BOTH: int
SB_LINEUP: int
SB_LINELEFT: int
SB_LINEDOWN: int
SB_LINERIGHT: int
SB_PAGEUP: int
SB_PAGELEFT: int
SB_PAGEDOWN: int
SB_PAGERIGHT: int
SB_THUMBPOSITION: int
SB_THUMBTRACK: int
SB_TOP: int
SB_LEFT: int
SB_BOTTOM: int
SB_RIGHT: int
SB_ENDSCROLL: int
SW_HIDE: int
SW_SHOWNORMAL: int
SW_NORMAL: int
SW_SHOWMINIMIZED: int
SW_SHOWMAXIMIZED: int
SW_MAXIMIZE: int
SW_SHOWNOACTIVATE: int
SW_SHOW: int
SW_MINIMIZE: int
SW_SHOWMINNOACTIVE: int
SW_SHOWNA: int
SW_RESTORE: int
SW_SHOWDEFAULT: int
SW_FORCEMINIMIZE: int
SW_MAX: int
HIDE_WINDOW: int
SHOW_OPENWINDOW: int
SHOW_ICONWINDOW: int
SHOW_FULLSCREEN: int
SHOW_OPENNOACTIVATE: int
SW_PARENTCLOSING: int
SW_OTHERZOOM: int
SW_PARENTOPENING: int
SW_OTHERUNZOOM: int
AW_HOR_POSITIVE: int
AW_HOR_NEGATIVE: int
AW_VER_POSITIVE: int
AW_VER_NEGATIVE: int
AW_CENTER: int
AW_HIDE: int
AW_ACTIVATE: int
AW_SLIDE: int
AW_BLEND: int
KF_EXTENDED: int
KF_DLGMODE: int
KF_MENUMODE: int
KF_ALTDOWN: int
KF_REPEAT: int
KF_UP: int
VK_LBUTTON: int
VK_RBUTTON: int
VK_CANCEL: int
VK_MBUTTON: int
VK_BACK: int
VK_TAB: int
VK_CLEAR: int
VK_RETURN: int
VK_SHIFT: int
VK_CONTROL: int
VK_MENU: int
VK_PAUSE: int
VK_CAPITAL: int
VK_KANA: int
VK_HANGEUL: int
VK_HANGUL: int
VK_JUNJA: int
VK_FINAL: int
VK_HANJA: int
VK_KANJI: int
VK_ESCAPE: int
VK_CONVERT: int
VK_NONCONVERT: int
VK_ACCEPT: int
VK_MODECHANGE: int
VK_SPACE: int
VK_PRIOR: int
VK_NEXT: int
VK_END: int
VK_HOME: int
VK_LEFT: int
VK_UP: int
VK_RIGHT: int
VK_DOWN: int
VK_SELECT: int
VK_PRINT: int
VK_EXECUTE: int
VK_SNAPSHOT: int
VK_INSERT: int
VK_DELETE: int
VK_HELP: int
VK_LWIN: int
VK_RWIN: int
VK_APPS: int
VK_NUMPAD0: int
VK_NUMPAD1: int
VK_NUMPAD2: int
VK_NUMPAD3: int
VK_NUMPAD4: int
VK_NUMPAD5: int
VK_NUMPAD6: int
VK_NUMPAD7: int
VK_NUMPAD8: int
VK_NUMPAD9: int
VK_MULTIPLY: int
VK_ADD: int
VK_SEPARATOR: int
VK_SUBTRACT: int
VK_DECIMAL: int
VK_DIVIDE: int
VK_F1: int
VK_F2: int
VK_F3: int
VK_F4: int
VK_F5: int
VK_F6: int
VK_F7: int
VK_F8: int
VK_F9: int
VK_F10: int
VK_F11: int
VK_F12: int
VK_F13: int
VK_F14: int
VK_F15: int
VK_F16: int
VK_F17: int
VK_F18: int
VK_F19: int
VK_F20: int
VK_F21: int
VK_F22: int
VK_F23: int
VK_F24: int
VK_NUMLOCK: int
VK_SCROLL: int
VK_LSHIFT: int
VK_RSHIFT: int
VK_LCONTROL: int
VK_RCONTROL: int
VK_LMENU: int
VK_RMENU: int
VK_PROCESSKEY: int
VK_ATTN: int
VK_CRSEL: int
VK_EXSEL: int
VK_EREOF: int
VK_PLAY: int
VK_ZOOM: int
VK_NONAME: int
VK_PA1: int
VK_OEM_CLEAR: int
MOUSEEVENTF_XDOWN: int
MOUSEEVENTF_XUP: int
MOUSEEVENTF_WHEEL: int
VK_XBUTTON1: int
VK_XBUTTON2: int
VK_VOLUME_MUTE: int
VK_VOLUME_DOWN: int
VK_VOLUME_UP: int
VK_MEDIA_NEXT_TRACK: int
VK_MEDIA_PREV_TRACK: int
VK_MEDIA_PLAY_PAUSE: int
VK_BROWSER_BACK: int
VK_BROWSER_FORWARD: int
WH_MIN: int
WH_MSGFILTER: int
WH_JOURNALRECORD: int
WH_JOURNALPLAYBACK: int
WH_KEYBOARD: int
WH_GETMESSAGE: int
WH_CALLWNDPROC: int
WH_CBT: int
WH_SYSMSGFILTER: int
WH_MOUSE: int
WH_HARDWARE: int
WH_DEBUG: int
WH_SHELL: int
WH_FOREGROUNDIDLE: int
WH_CALLWNDPROCRET: int
WH_KEYBOARD_LL: int
WH_MOUSE_LL: int
WH_MAX: int
WH_MINHOOK: int
WH_MAXHOOK: int
HC_ACTION: int
HC_GETNEXT: int
HC_SKIP: int
HC_NOREMOVE: int
HC_NOREM: int
HC_SYSMODALON: int
HC_SYSMODALOFF: int
HCBT_MOVESIZE: int
HCBT_MINMAX: int
HCBT_QS: int
HCBT_CREATEWND: int
HCBT_DESTROYWND: int
HCBT_ACTIVATE: int
HCBT_CLICKSKIPPED: int
HCBT_KEYSKIPPED: int
HCBT_SYSCOMMAND: int
HCBT_SETFOCUS: int
MSGF_DIALOGBOX: int
MSGF_MESSAGEBOX: int
MSGF_MENU: int
MSGF_SCROLLBAR: int
MSGF_NEXTWINDOW: int
MSGF_MAX: int
MSGF_USER: int
HSHELL_WINDOWCREATED: int
HSHELL_WINDOWDESTROYED: int
HSHELL_ACTIVATESHELLWINDOW: int
HSHELL_WINDOWACTIVATED: int
HSHELL_GETMINRECT: int
HSHELL_REDRAW: int
HSHELL_TASKMAN: int
HSHELL_LANGUAGE: int
HSHELL_ACCESSIBILITYSTATE: int
ACCESS_STICKYKEYS: int
ACCESS_FILTERKEYS: int
ACCESS_MOUSEKEYS: int
LLKHF_EXTENDED: int
LLKHF_INJECTED: int
LLKHF_ALTDOWN: int
LLKHF_UP: int
LLKHF_LOWER_IL_INJECTED: int
LLMHF_INJECTED: int
LLMHF_LOWER_IL_INJECTED: int
HKL_PREV: int
HKL_NEXT: int
KLF_ACTIVATE: int
KLF_SUBSTITUTE_OK: int
KLF_UNLOADPREVIOUS: int
KLF_REORDER: int
KLF_REPLACELANG: int
KLF_NOTELLSHELL: int
KLF_SETFORPROCESS: int
KL_NAMELENGTH: int
DESKTOP_READOBJECTS: int
DESKTOP_CREATEWINDOW: int
DESKTOP_CREATEMENU: int
DESKTOP_HOOKCONTROL: int
DESKTOP_JOURNALRECORD: int
DESKTOP_JOURNALPLAYBACK: int
DESKTOP_ENUMERATE: int
DESKTOP_WRITEOBJECTS: int
DESKTOP_SWITCHDESKTOP: int
DF_ALLOWOTHERACCOUNTHOOK: int
WINSTA_ENUMDESKTOPS: int
WINSTA_READATTRIBUTES: int
WINSTA_ACCESSCLIPBOARD: int
WINSTA_CREATEDESKTOP: int
WINSTA_WRITEATTRIBUTES: int
WINSTA_ACCESSGLOBALATOMS: int
WINSTA_EXITWINDOWS: int
WINSTA_ENUMERATE: int
WINSTA_READSCREEN: int
WSF_VISIBLE: int
UOI_FLAGS: int
UOI_NAME: int
UOI_TYPE: int
UOI_USER_SID: int
GWL_WNDPROC: int
GWL_HINSTANCE: int
GWL_HWNDPARENT: int
GWL_STYLE: int
GWL_EXSTYLE: int
GWL_USERDATA: int
GWL_ID: int
GCL_MENUNAME: int
GCL_HBRBACKGROUND: int
GCL_HCURSOR: int
GCL_HICON: int
GCL_HMODULE: int
GCL_CBWNDEXTRA: int
GCL_CBCLSEXTRA: int
GCL_WNDPROC: int
GCL_STYLE: int
GCW_ATOM: int
GCL_HICONSM: int
WM_NULL: int
WM_CREATE: int
WM_DESTROY: int
WM_MOVE: int
WM_SIZE: int
WM_ACTIVATE: int
WA_INACTIVE: int
WA_ACTIVE: int
WA_CLICKACTIVE: int
WM_SETFOCUS: int
WM_KILLFOCUS: int
WM_ENABLE: int
WM_SETREDRAW: int
WM_SETTEXT: int
WM_GETTEXT: int
WM_GETTEXTLENGTH: int
WM_PAINT: int
WM_CLOSE: int
WM_QUERYENDSESSION: int
WM_QUIT: int
WM_QUERYOPEN: int
WM_ERASEBKGND: int
WM_SYSCOLORCHANGE: int
WM_ENDSESSION: int
WM_SHOWWINDOW: int
WM_WININICHANGE: int
WM_SETTINGCHANGE: int
WM_DEVMODECHANGE: int
WM_ACTIVATEAPP: int
WM_FONTCHANGE: int
WM_TIMECHANGE: int
WM_CANCELMODE: int
WM_SETCURSOR: int
WM_MOUSEACTIVATE: int
WM_CHILDACTIVATE: int
WM_QUEUESYNC: int
WM_GETMINMAXINFO: int
WM_PAINTICON: int
WM_ICONERASEBKGND: int
WM_NEXTDLGCTL: int
WM_SPOOLERSTATUS: int
WM_DRAWITEM: int
WM_MEASUREITEM: int
WM_DELETEITEM: int
WM_VKEYTOITEM: int
WM_CHARTOITEM: int
WM_SETFONT: int
WM_GETFONT: int
WM_SETHOTKEY: int
WM_GETHOTKEY: int
WM_QUERYDRAGICON: int
WM_COMPAREITEM: int
WM_GETOBJECT: int
WM_COMPACTING: int
WM_COMMNOTIFY: int
WM_WINDOWPOSCHANGING: int
WM_WINDOWPOSCHANGED: int
WM_POWER: int
PWR_OK: int
PWR_FAIL: int
PWR_SUSPENDREQUEST: int
PWR_SUSPENDRESUME: int
PWR_CRITICALRESUME: int
WM_COPYDATA: int
WM_CANCELJOURNAL: int
WM_NOTIFY: int
WM_INPUTLANGCHANGEREQUEST: int
WM_INPUTLANGCHANGE: int
WM_TCARD: int
WM_HELP: int
WM_USERCHANGED: int
WM_NOTIFYFORMAT: int
NFR_ANSI: int
NFR_UNICODE: int
NF_QUERY: int
NF_REQUERY: int
WM_CONTEXTMENU: int
WM_STYLECHANGING: int
WM_STYLECHANGED: int
WM_DISPLAYCHANGE: int
WM_GETICON: int
WM_SETICON: int
WM_NCCREATE: int
WM_NCDESTROY: int
WM_NCCALCSIZE: int
WM_NCHITTEST: int
WM_NCPAINT: int
WM_NCACTIVATE: int
WM_GETDLGCODE: int
WM_SYNCPAINT: int
WM_NCMOUSEMOVE: int
WM_NCLBUTTONDOWN: int
WM_NCLBUTTONUP: int
WM_NCLBUTTONDBLCLK: int
WM_NCRBUTTONDOWN: int
WM_NCRBUTTONUP: int
WM_NCRBUTTONDBLCLK: int
WM_NCMBUTTONDOWN: int
WM_NCMBUTTONUP: int
WM_NCMBUTTONDBLCLK: int
WM_KEYFIRST: int
WM_KEYDOWN: int
WM_KEYUP: int
WM_CHAR: int
WM_DEADCHAR: int
WM_SYSKEYDOWN: int
WM_SYSKEYUP: int
WM_SYSCHAR: int
WM_SYSDEADCHAR: int
WM_KEYLAST: int
WM_IME_STARTCOMPOSITION: int
WM_IME_ENDCOMPOSITION: int
WM_IME_COMPOSITION: int
WM_IME_KEYLAST: int
WM_INITDIALOG: int
WM_COMMAND: int
WM_SYSCOMMAND: int
WM_TIMER: int
WM_HSCROLL: int
WM_VSCROLL: int
WM_INITMENU: int
WM_INITMENUPOPUP: int
WM_MENUSELECT: int
WM_MENUCHAR: int
WM_ENTERIDLE: int
WM_MENURBUTTONUP: int
WM_MENUDRAG: int
WM_MENUGETOBJECT: int
WM_UNINITMENUPOPUP: int
WM_MENUCOMMAND: int
WM_CTLCOLORMSGBOX: int
WM_CTLCOLOREDIT: int
WM_CTLCOLORBTN: int
WM_CTLCOLORDLG: int
WM_CTLCOLORSCROLLBAR: int
WM_CTLCOLORSTATIC: int
WM_MOUSEFIRST: int
WM_MOUSEMOVE: int
WM_LBUTTONDOWN: int
WM_LBUTTONUP: int
WM_LBUTTONDBLCLK: int
WM_RBUTTONDOWN: int
WM_RBUTTONUP: int
WM_RBUTTONDBLCLK: int
WM_MBUTTONDOWN: int
WM_MBUTTONUP: int
WM_MBUTTONDBLCLK: int
WM_MOUSEWHEEL: int
WM_MOUSELAST: int
WHEEL_DELTA: int
WHEEL_PAGESCROLL: int
WM_PARENTNOTIFY: int
MENULOOP_WINDOW: int
MENULOOP_POPUP: int
WM_ENTERMENULOOP: int
WM_EXITMENULOOP: int
WM_NEXTMENU: int
WM_SIZING: int
WM_CAPTURECHANGED: int
WM_MOVING: int
WM_POWERBROADCAST: int
PBT_APMQUERYSUSPEND: int
PBT_APMQUERYSTANDBY: int
PBT_APMQUERYSUSPENDFAILED: int
PBT_APMQUERYSTANDBYFAILED: int
PBT_APMSUSPEND: int
PBT_APMSTANDBY: int
PBT_APMRESUMECRITICAL: int
PBT_APMRESUMESUSPEND: int
PBT_APMRESUMESTANDBY: int
PBTF_APMRESUMEFROMFAILURE: int
PBT_APMBATTERYLOW: int
PBT_APMPOWERSTATUSCHANGE: int
PBT_APMOEMEVENT: int
PBT_APMRESUMEAUTOMATIC: int
WM_DEVICECHANGE: int
WM_MDICREATE: int
WM_MDIDESTROY: int
WM_MDIACTIVATE: int
WM_MDIRESTORE: int
WM_MDINEXT: int
WM_MDIMAXIMIZE: int
WM_MDITILE: int
WM_MDICASCADE: int
WM_MDIICONARRANGE: int
WM_MDIGETACTIVE: int
WM_MDISETMENU: int
WM_ENTERSIZEMOVE: int
WM_EXITSIZEMOVE: int
WM_DROPFILES: int
WM_MDIREFRESHMENU: int
WM_IME_SETCONTEXT: int
WM_IME_NOTIFY: int
WM_IME_CONTROL: int
WM_IME_COMPOSITIONFULL: int
WM_IME_SELECT: int
WM_IME_CHAR: int
WM_IME_REQUEST: int
WM_IME_KEYDOWN: int
WM_IME_KEYUP: int
WM_MOUSEHOVER: int
WM_MOUSELEAVE: int
WM_CUT: int
WM_COPY: int
WM_PASTE: int
WM_CLEAR: int
WM_UNDO: int
WM_RENDERFORMAT: int
WM_RENDERALLFORMATS: int
WM_DESTROYCLIPBOARD: int
WM_DRAWCLIPBOARD: int
WM_PAINTCLIPBOARD: int
WM_VSCROLLCLIPBOARD: int
WM_SIZECLIPBOARD: int
WM_ASKCBFORMATNAME: int
WM_CHANGECBCHAIN: int
WM_HSCROLLCLIPBOARD: int
WM_QUERYNEWPALETTE: int
WM_PALETTEISCHANGING: int
WM_PALETTECHANGED: int
WM_HOTKEY: int
WM_PRINT: int
WM_PRINTCLIENT: int
WM_HANDHELDFIRST: int
WM_HANDHELDLAST: int
WM_AFXFIRST: int
WM_AFXLAST: int
WM_PENWINFIRST: int
WM_PENWINLAST: int
WM_APP: int
WMSZ_LEFT: int
WMSZ_RIGHT: int
WMSZ_TOP: int
WMSZ_TOPLEFT: int
WMSZ_TOPRIGHT: int
WMSZ_BOTTOM: int
WMSZ_BOTTOMLEFT: int
WMSZ_BOTTOMRIGHT: int
HTERROR: int
HTTRANSPARENT: int
HTNOWHERE: int
HTCLIENT: int
HTCAPTION: int
HTSYSMENU: int
HTGROWBOX: int
HTSIZE: int
HTMENU: int
HTHSCROLL: int
HTVSCROLL: int
HTMINBUTTON: int
HTMAXBUTTON: int
HTLEFT: int
HTRIGHT: int
HTTOP: int
HTTOPLEFT: int
HTTOPRIGHT: int
HTBOTTOM: int
HTBOTTOMLEFT: int
HTBOTTOMRIGHT: int
HTBORDER: int
HTREDUCE: int
HTZOOM: int
HTSIZEFIRST: int
HTSIZELAST: int
HTOBJECT: int
HTCLOSE: int
HTHELP: int
SMTO_NORMAL: int
SMTO_BLOCK: int
SMTO_ABORTIFHUNG: int
SMTO_NOTIMEOUTIFNOTHUNG: int
MA_ACTIVATE: int
MA_ACTIVATEANDEAT: int
MA_NOACTIVATE: int
MA_NOACTIVATEANDEAT: int
ICON_SMALL: int
ICON_BIG: int
SIZE_RESTORED: int
SIZE_MINIMIZED: int
SIZE_MAXIMIZED: int
SIZE_MAXSHOW: int
SIZE_MAXHIDE: int
SIZENORMAL: int
SIZEICONIC: int
SIZEFULLSCREEN: int
SIZEZOOMSHOW: int
SIZEZOOMHIDE: int
WVR_ALIGNTOP: int
WVR_ALIGNLEFT: int
WVR_ALIGNBOTTOM: int
WVR_ALIGNRIGHT: int
WVR_HREDRAW: int
WVR_VREDRAW: int
WVR_REDRAW: int
WVR_VALIDRECTS: int
MK_LBUTTON: int
MK_RBUTTON: int
MK_SHIFT: int
MK_CONTROL: int
MK_MBUTTON: int
TME_HOVER: int
TME_LEAVE: int
TME_QUERY: int
TME_CANCEL: int
HOVER_DEFAULT: int
WS_OVERLAPPED: int
WS_POPUP: int
WS_CHILD: int
WS_MINIMIZE: int
WS_VISIBLE: int
WS_DISABLED: int
WS_CLIPSIBLINGS: int
WS_CLIPCHILDREN: int
WS_MAXIMIZE: int
WS_CAPTION: int
WS_BORDER: int
WS_DLGFRAME: int
WS_VSCROLL: int
WS_HSCROLL: int
WS_SYSMENU: int
WS_THICKFRAME: int
WS_GROUP: int
WS_TABSTOP: int
WS_MINIMIZEBOX: int
WS_MAXIMIZEBOX: int
WS_TILED: int
WS_ICONIC: int
WS_SIZEBOX: int
WS_OVERLAPPEDWINDOW: int
WS_POPUPWINDOW: int
WS_CHILDWINDOW: int
WS_TILEDWINDOW: int
WS_EX_DLGMODALFRAME: int
WS_EX_NOPARENTNOTIFY: int
WS_EX_TOPMOST: int
WS_EX_ACCEPTFILES: int
WS_EX_TRANSPARENT: int
WS_EX_MDICHILD: int
WS_EX_TOOLWINDOW: int
WS_EX_WINDOWEDGE: int
WS_EX_CLIENTEDGE: int
WS_EX_CONTEXTHELP: int
WS_EX_RIGHT: int
WS_EX_LEFT: int
WS_EX_RTLREADING: int
WS_EX_LTRREADING: int
WS_EX_LEFTSCROLLBAR: int
WS_EX_RIGHTSCROLLBAR: int
WS_EX_CONTROLPARENT: int
WS_EX_STATICEDGE: int
WS_EX_APPWINDOW: int
WS_EX_OVERLAPPEDWINDOW: int
WS_EX_PALETTEWINDOW: int
WS_EX_LAYERED: int
WS_EX_NOINHERITLAYOUT: int
WS_EX_LAYOUTRTL: int
WS_EX_COMPOSITED: int
WS_EX_NOACTIVATE: int
CS_VREDRAW: int
CS_HREDRAW: int
CS_DBLCLKS: int
CS_OWNDC: int
CS_CLASSDC: int
CS_PARENTDC: int
CS_NOCLOSE: int
CS_SAVEBITS: int
CS_BYTEALIGNCLIENT: int
CS_BYTEALIGNWINDOW: int
CS_GLOBALCLASS: int
CS_IME: int
PRF_CHECKVISIBLE: int
PRF_NONCLIENT: int
PRF_CLIENT: int
PRF_ERASEBKGND: int
PRF_CHILDREN: int
PRF_OWNED: int
BDR_RAISEDOUTER: int
BDR_SUNKENOUTER: int
BDR_RAISEDINNER: int
BDR_SUNKENINNER: int
BDR_OUTER: int
BDR_INNER: int
EDGE_RAISED: int
EDGE_SUNKEN: int
EDGE_ETCHED: int
EDGE_BUMP: int
ISMEX_NOSEND: int
ISMEX_SEND: int
ISMEX_NOTIFY: int
ISMEX_CALLBACK: int
ISMEX_REPLIED: int
CW_USEDEFAULT: int
FLASHW_STOP: int
FLASHW_CAPTION: int
FLASHW_TRAY: int
FLASHW_ALL: int
FLASHW_TIMER: int
FLASHW_TIMERNOFG: int
DS_ABSALIGN: int
DS_SYSMODAL: int
DS_LOCALEDIT: int
DS_SETFONT: int
DS_MODALFRAME: int
DS_NOIDLEMSG: int
DS_SETFOREGROUND: int
DS_3DLOOK: int
DS_FIXEDSYS: int
DS_NOFAILCREATE: int
DS_CONTROL: int
DS_CENTER: int
DS_CENTERMOUSE: int
DS_CONTEXTHELP: int
DM_GETDEFID: int
DM_SETDEFID: int
DM_REPOSITION: int
DC_HASDEFID: int
DLGC_WANTARROWS: int
DLGC_WANTTAB: int
DLGC_WANTALLKEYS: int
DLGC_WANTMESSAGE: int
DLGC_HASSETSEL: int
DLGC_DEFPUSHBUTTON: int
DLGC_UNDEFPUSHBUTTON: int
DLGC_RADIOBUTTON: int
DLGC_WANTCHARS: int
DLGC_STATIC: int
DLGC_BUTTON: int
LB_CTLCODE: int
LB_OKAY: int
LB_ERR: int
LB_ERRSPACE: int
LBN_ERRSPACE: int
LBN_SELCHANGE: int
LBN_DBLCLK: int
LBN_SELCANCEL: int
LBN_SETFOCUS: int
LBN_KILLFOCUS: int
LB_ADDSTRING: int
LB_INSERTSTRING: int
LB_DELETESTRING: int
LB_SELITEMRANGEEX: int
LB_RESETCONTENT: int
LB_SETSEL: int
LB_SETCURSEL: int
LB_GETSEL: int
LB_GETCURSEL: int
LB_GETTEXT: int
LB_GETTEXTLEN: int
LB_GETCOUNT: int
LB_SELECTSTRING: int
LB_DIR: int
LB_GETTOPINDEX: int
LB_FINDSTRING: int
LB_GETSELCOUNT: int
LB_GETSELITEMS: int
LB_SETTABSTOPS: int
LB_GETHORIZONTALEXTENT: int
LB_SETHORIZONTALEXTENT: int
LB_SETCOLUMNWIDTH: int
LB_ADDFILE: int
LB_SETTOPINDEX: int
LB_GETITEMRECT: int
LB_GETITEMDATA: int
LB_SETITEMDATA: int
LB_SELITEMRANGE: int
LB_SETANCHORINDEX: int
LB_GETANCHORINDEX: int
LB_SETCARETINDEX: int
LB_GETCARETINDEX: int
LB_SETITEMHEIGHT: int
LB_GETITEMHEIGHT: int
LB_FINDSTRINGEXACT: int
LB_SETLOCALE: int
LB_GETLOCALE: int
LB_SETCOUNT: int
LB_INITSTORAGE: int
LB_ITEMFROMPOINT: int
LB_MSGMAX: int
LBS_NOTIFY: int
LBS_SORT: int
LBS_NOREDRAW: int
LBS_MULTIPLESEL: int
LBS_OWNERDRAWFIXED: int
LBS_OWNERDRAWVARIABLE: int
LBS_HASSTRINGS: int
LBS_USETABSTOPS: int
LBS_NOINTEGRALHEIGHT: int
LBS_MULTICOLUMN: int
LBS_WANTKEYBOARDINPUT: int
LBS_EXTENDEDSEL: int
LBS_DISABLENOSCROLL: int
LBS_NODATA: int
LBS_NOSEL: int
LBS_STANDARD: int
CB_OKAY: int
CB_ERR: int
CB_ERRSPACE: int
CBN_ERRSPACE: int
CBN_SELCHANGE: int
CBN_DBLCLK: int
CBN_SETFOCUS: int
CBN_KILLFOCUS: int
CBN_EDITCHANGE: int
CBN_EDITUPDATE: int
CBN_DROPDOWN: int
CBN_CLOSEUP: int
CBN_SELENDOK: int
CBN_SELENDCANCEL: int
CBS_SIMPLE: int
CBS_DROPDOWN: int
CBS_OWNERDRAWFIXED: int
CBS_OWNERDRAWVARIABLE: int
CBS_AUTOHSCROLL: int
CBS_OEMCONVERT: int
CBS_SORT: int
CBS_HASSTRINGS: int
CBS_NOINTEGRALHEIGHT: int
CBS_DISABLENOSCROLL: int
CBS_UPPERCASE: int
CBS_LOWERCASE: int
CB_GETEDITSEL: int
CB_LIMITTEXT: int
CB_SETEDITSEL: int
CB_ADDSTRING: int
CB_DELETESTRING: int
CB_DIR: int
CB_GETCOUNT: int
CB_GETCURSEL: int
CB_GETLBTEXT: int
CB_GETLBTEXTLEN: int
CB_INSERTSTRING: int
CB_RESETCONTENT: int
CB_FINDSTRING: int
CB_SELECTSTRING: int
CB_SETCURSEL: int
CB_SHOWDROPDOWN: int
CB_GETITEMDATA: int
CB_SETITEMDATA: int
CB_GETDROPPEDCONTROLRECT: int
CB_SETITEMHEIGHT: int
CB_GETITEMHEIGHT: int
CB_SETEXTENDEDUI: int
CB_GETEXTENDEDUI: int
CB_GETDROPPEDSTATE: int
CB_FINDSTRINGEXACT: int
CB_SETLOCALE: int
CB_GETLOCALE: int
CB_GETTOPINDEX: int
CB_SETTOPINDEX: int
CB_GETHORIZONTALEXTENT: int
CB_SETHORIZONTALEXTENT: int
CB_GETDROPPEDWIDTH: int
CB_SETDROPPEDWIDTH: int
CB_INITSTORAGE: int
CB_MSGMAX: int
SBS_HORZ: int
SBS_VERT: int
SBS_TOPALIGN: int
SBS_LEFTALIGN: int
SBS_BOTTOMALIGN: int
SBS_RIGHTALIGN: int
SBS_SIZEBOXTOPLEFTALIGN: int
SBS_SIZEBOXBOTTOMRIGHTALIGN: int
SBS_SIZEBOX: int
SBS_SIZEGRIP: int
SBM_SETPOS: int
SBM_GETPOS: int
SBM_SETRANGE: int
SBM_SETRANGEREDRAW: int
SBM_GETRANGE: int
SBM_ENABLE_ARROWS: int
SBM_SETSCROLLINFO: int
SBM_GETSCROLLINFO: int
SIF_RANGE: int
SIF_PAGE: int
SIF_POS: int
SIF_DISABLENOSCROLL: int
SIF_TRACKPOS: int
SIF_ALL: int
MDIS_ALLCHILDSTYLES: int
MDITILE_VERTICAL: int
MDITILE_HORIZONTAL: int
MDITILE_SKIPDISABLED: int
IMC_GETCANDIDATEPOS: int
IMC_SETCANDIDATEPOS: int
IMC_GETCOMPOSITIONFONT: int
IMC_SETCOMPOSITIONFONT: int
IMC_GETCOMPOSITIONWINDOW: int
IMC_SETCOMPOSITIONWINDOW: int
IMC_GETSTATUSWINDOWPOS: int
IMC_SETSTATUSWINDOWPOS: int
IMC_CLOSESTATUSWINDOW: int
IMC_OPENSTATUSWINDOW: int
DELETE: int
READ_CONTROL: int
WRITE_DAC: int
WRITE_OWNER: int
SYNCHRONIZE: int
STANDARD_RIGHTS_REQUIRED: int
STANDARD_RIGHTS_READ: int
STANDARD_RIGHTS_WRITE: int
STANDARD_RIGHTS_EXECUTE: int
STANDARD_RIGHTS_ALL: int
SPECIFIC_RIGHTS_ALL: int
ACCESS_SYSTEM_SECURITY: int
MAXIMUM_ALLOWED: int
GENERIC_READ: int
GENERIC_WRITE: int
GENERIC_EXECUTE: int
GENERIC_ALL: int
SERVICE_KERNEL_DRIVER: int
SERVICE_FILE_SYSTEM_DRIVER: int
SERVICE_ADAPTER: int
SERVICE_RECOGNIZER_DRIVER: int
SERVICE_DRIVER: int
SERVICE_WIN32_OWN_PROCESS: int
SERVICE_WIN32_SHARE_PROCESS: int
SERVICE_WIN32: int
SERVICE_INTERACTIVE_PROCESS: int
SERVICE_TYPE_ALL: int
SERVICE_BOOT_START: int
SERVICE_SYSTEM_START: int
SERVICE_AUTO_START: int
SERVICE_DEMAND_START: int
SERVICE_DISABLED: int
SERVICE_ERROR_IGNORE: int
SERVICE_ERROR_NORMAL: int
SERVICE_ERROR_SEVERE: int
SERVICE_ERROR_CRITICAL: int
TAPE_ERASE_SHORT: int
TAPE_ERASE_LONG: int
TAPE_LOAD: int
TAPE_UNLOAD: int
TAPE_TENSION: int
TAPE_LOCK: int
TAPE_UNLOCK: int
TAPE_FORMAT: int
TAPE_SETMARKS: int
TAPE_FILEMARKS: int
TAPE_SHORT_FILEMARKS: int
TAPE_LONG_FILEMARKS: int
TAPE_ABSOLUTE_POSITION: int
TAPE_LOGICAL_POSITION: int
TAPE_PSEUDO_LOGICAL_POSITION: int
TAPE_REWIND: int
TAPE_ABSOLUTE_BLOCK: int
TAPE_LOGICAL_BLOCK: int
TAPE_PSEUDO_LOGICAL_BLOCK: int
TAPE_SPACE_END_OF_DATA: int
TAPE_SPACE_RELATIVE_BLOCKS: int
TAPE_SPACE_FILEMARKS: int
TAPE_SPACE_SEQUENTIAL_FMKS: int
TAPE_SPACE_SETMARKS: int
TAPE_SPACE_SEQUENTIAL_SMKS: int
TAPE_DRIVE_FIXED: int
TAPE_DRIVE_SELECT: int
TAPE_DRIVE_INITIATOR: int
TAPE_DRIVE_ERASE_SHORT: int
TAPE_DRIVE_ERASE_LONG: int
TAPE_DRIVE_ERASE_BOP_ONLY: int
TAPE_DRIVE_ERASE_IMMEDIATE: int
TAPE_DRIVE_TAPE_CAPACITY: int
TAPE_DRIVE_TAPE_REMAINING: int
TAPE_DRIVE_FIXED_BLOCK: int
TAPE_DRIVE_VARIABLE_BLOCK: int
TAPE_DRIVE_WRITE_PROTECT: int
TAPE_DRIVE_EOT_WZ_SIZE: int
TAPE_DRIVE_ECC: int
TAPE_DRIVE_COMPRESSION: int
TAPE_DRIVE_PADDING: int
TAPE_DRIVE_REPORT_SMKS: int
TAPE_DRIVE_GET_ABSOLUTE_BLK: int
TAPE_DRIVE_GET_LOGICAL_BLK: int
TAPE_DRIVE_SET_EOT_WZ_SIZE: int
TAPE_DRIVE_LOAD_UNLOAD: int
TAPE_DRIVE_TENSION: int
TAPE_DRIVE_LOCK_UNLOCK: int
TAPE_DRIVE_REWIND_IMMEDIATE: int
TAPE_DRIVE_SET_BLOCK_SIZE: int
TAPE_DRIVE_LOAD_UNLD_IMMED: int
TAPE_DRIVE_TENSION_IMMED: int
TAPE_DRIVE_LOCK_UNLK_IMMED: int
TAPE_DRIVE_SET_ECC: int
TAPE_DRIVE_SET_COMPRESSION: int
TAPE_DRIVE_SET_PADDING: int
TAPE_DRIVE_SET_REPORT_SMKS: int
TAPE_DRIVE_ABSOLUTE_BLK: int
TAPE_DRIVE_ABS_BLK_IMMED: int
TAPE_DRIVE_LOGICAL_BLK: int
TAPE_DRIVE_LOG_BLK_IMMED: int
TAPE_DRIVE_END_OF_DATA: int
TAPE_DRIVE_RELATIVE_BLKS: int
TAPE_DRIVE_FILEMARKS: int
TAPE_DRIVE_SEQUENTIAL_FMKS: int
TAPE_DRIVE_SETMARKS: int
TAPE_DRIVE_SEQUENTIAL_SMKS: int
TAPE_DRIVE_REVERSE_POSITION: int
TAPE_DRIVE_SPACE_IMMEDIATE: int
TAPE_DRIVE_WRITE_SETMARKS: int
TAPE_DRIVE_WRITE_FILEMARKS: int
TAPE_DRIVE_WRITE_SHORT_FMKS: int
TAPE_DRIVE_WRITE_LONG_FMKS: int
TAPE_DRIVE_WRITE_MARK_IMMED: int
TAPE_DRIVE_FORMAT: int
TAPE_DRIVE_FORMAT_IMMEDIATE: int
TAPE_FIXED_PARTITIONS: int
TAPE_SELECT_PARTITIONS: int
TAPE_INITIATOR_PARTITIONS: int
APPLICATION_ERROR_MASK: int
ERROR_SEVERITY_SUCCESS: int
ERROR_SEVERITY_INFORMATIONAL: int
ERROR_SEVERITY_WARNING: int
ERROR_SEVERITY_ERROR: int
MINCHAR: int
MAXCHAR: int
MINSHORT: int
MAXSHORT: int
MINLONG: int
MAXLONG: int
MAXBYTE: int
MAXWORD: int
MAXDWORD: int
LANG_NEUTRAL: int
LANG_BULGARIAN: int
LANG_CHINESE: int
LANG_CROATIAN: int
LANG_CZECH: int
LANG_DANISH: int
LANG_DUTCH: int
LANG_ENGLISH: int
LANG_FINNISH: int
LANG_FRENCH: int
LANG_GERMAN: int
LANG_GREEK: int
LANG_HUNGARIAN: int
LANG_ICELANDIC: int
LANG_ITALIAN: int
LANG_JAPANESE: int
LANG_KOREAN: int
LANG_NORWEGIAN: int
LANG_POLISH: int
LANG_PORTUGUESE: int
LANG_ROMANIAN: int
LANG_RUSSIAN: int
LANG_SLOVAK: int
LANG_SLOVENIAN: int
LANG_SPANISH: int
LANG_SWEDISH: int
LANG_TURKISH: int
SUBLANG_NEUTRAL: int
SUBLANG_DEFAULT: int
SUBLANG_SYS_DEFAULT: int
SUBLANG_CHINESE_TRADITIONAL: int
SUBLANG_CHINESE_SIMPLIFIED: int
SUBLANG_CHINESE_HONGKONG: int
SUBLANG_CHINESE_SINGAPORE: int
SUBLANG_DUTCH: int
SUBLANG_DUTCH_BELGIAN: int
SUBLANG_ENGLISH_US: int
SUBLANG_ENGLISH_UK: int
SUBLANG_ENGLISH_AUS: int
SUBLANG_ENGLISH_CAN: int
SUBLANG_ENGLISH_NZ: int
SUBLANG_ENGLISH_EIRE: int
SUBLANG_FRENCH: int
SUBLANG_FRENCH_BELGIAN: int
SUBLANG_FRENCH_CANADIAN: int
SUBLANG_FRENCH_SWISS: int
SUBLANG_GERMAN: int
SUBLANG_GERMAN_SWISS: int
SUBLANG_GERMAN_AUSTRIAN: int
SUBLANG_ITALIAN: int
SUBLANG_ITALIAN_SWISS: int
SUBLANG_NORWEGIAN_BOKMAL: int
SUBLANG_NORWEGIAN_NYNORSK: int
SUBLANG_PORTUGUESE: int
SUBLANG_PORTUGUESE_BRAZILIAN: int
SUBLANG_SPANISH: int
SUBLANG_SPANISH_MEXICAN: int
SUBLANG_SPANISH_MODERN: int
SORT_DEFAULT: int
SORT_JAPANESE_XJIS: int
SORT_JAPANESE_UNICODE: int
SORT_CHINESE_BIG5: int
SORT_CHINESE_UNICODE: int
SORT_KOREAN_KSC: int
SORT_KOREAN_UNICODE: int

def PRIMARYLANGID(lgid: int) -> int: ...
def SUBLANGID(lgid: int) -> int: ...

NLS_VALID_LOCALE_MASK: int
CONTEXT_PORTABLE_32BIT: int
CONTEXT_ALPHA: int
SIZE_OF_80387_REGISTERS: int
CONTEXT_CONTROL: int
CONTEXT_FLOATING_POINT: int
CONTEXT_INTEGER: int
CONTEXT_FULL: int
PROCESS_TERMINATE: int
PROCESS_CREATE_THREAD: int
PROCESS_VM_OPERATION: int
PROCESS_VM_READ: int
PROCESS_VM_WRITE: int
PROCESS_DUP_HANDLE: int
PROCESS_CREATE_PROCESS: int
PROCESS_SET_QUOTA: int
PROCESS_SET_INFORMATION: int
PROCESS_QUERY_INFORMATION: int
PROCESS_SUSPEND_RESUME: int
PROCESS_QUERY_LIMITED_INFORMATION: int
PROCESS_SET_LIMITED_INFORMATION: int
PROCESS_ALL_ACCESS: int
THREAD_TERMINATE: int
THREAD_SUSPEND_RESUME: int
THREAD_GET_CONTEXT: int
THREAD_SET_CONTEXT: int
THREAD_SET_INFORMATION: int
THREAD_QUERY_INFORMATION: int
THREAD_SET_THREAD_TOKEN: int
THREAD_IMPERSONATE: int
THREAD_DIRECT_IMPERSONATION: int
THREAD_SET_LIMITED_INFORMATION: int
THREAD_QUERY_LIMITED_INFORMATION: int
THREAD_RESUME: int
TLS_MINIMUM_AVAILABLE: int
EVENT_MODIFY_STATE: int
MUTANT_QUERY_STATE: int
SEMAPHORE_MODIFY_STATE: int
TIME_ZONE_ID_UNKNOWN: int
TIME_ZONE_ID_STANDARD: int
TIME_ZONE_ID_DAYLIGHT: int
PROCESSOR_INTEL_386: int
PROCESSOR_INTEL_486: int
PROCESSOR_INTEL_PENTIUM: int
PROCESSOR_INTEL_860: int
PROCESSOR_MIPS_R2000: int
PROCESSOR_MIPS_R3000: int
PROCESSOR_MIPS_R4000: int
PROCESSOR_ALPHA_21064: int
PROCESSOR_PPC_601: int
PROCESSOR_PPC_603: int
PROCESSOR_PPC_604: int
PROCESSOR_PPC_620: int
SECTION_QUERY: int
SECTION_MAP_WRITE: int
SECTION_MAP_READ: int
SECTION_MAP_EXECUTE: int
SECTION_EXTEND_SIZE: int
PAGE_NOACCESS: int
PAGE_READONLY: int
PAGE_READWRITE: int
PAGE_WRITECOPY: int
PAGE_EXECUTE: int
PAGE_EXECUTE_READ: int
PAGE_EXECUTE_READWRITE: int
PAGE_EXECUTE_WRITECOPY: int
PAGE_GUARD: int
PAGE_NOCACHE: int
MEM_COMMIT: int
MEM_RESERVE: int
MEM_DECOMMIT: int
MEM_RELEASE: int
MEM_FREE: int
MEM_PRIVATE: int
MEM_MAPPED: int
MEM_TOP_DOWN: int
SEC_FILE: int
SEC_IMAGE: int
SEC_RESERVE: int
SEC_COMMIT: int
SEC_NOCACHE: int
MEM_IMAGE: int
FILE_SHARE_READ: int
FILE_SHARE_WRITE: int
FILE_SHARE_DELETE: int
FILE_ATTRIBUTE_READONLY: int
FILE_ATTRIBUTE_HIDDEN: int
FILE_ATTRIBUTE_SYSTEM: int
FILE_ATTRIBUTE_DIRECTORY: int
FILE_ATTRIBUTE_ARCHIVE: int
FILE_ATTRIBUTE_DEVICE: int
FILE_ATTRIBUTE_NORMAL: int
FILE_ATTRIBUTE_TEMPORARY: int
FILE_ATTRIBUTE_SPARSE_FILE: int
FILE_ATTRIBUTE_REPARSE_POINT: int
FILE_ATTRIBUTE_COMPRESSED: int
FILE_ATTRIBUTE_OFFLINE: int
FILE_ATTRIBUTE_NOT_CONTENT_INDEXED: int
FILE_ATTRIBUTE_ENCRYPTED: int
FILE_ATTRIBUTE_VIRTUAL: int
FILE_ATTRIBUTE_ATOMIC_WRITE: int
FILE_ATTRIBUTE_XACTION_WRITE: int
FILE_NOTIFY_CHANGE_FILE_NAME: int
FILE_NOTIFY_CHANGE_DIR_NAME: int
FILE_NOTIFY_CHANGE_ATTRIBUTES: int
FILE_NOTIFY_CHANGE_SIZE: int
FILE_NOTIFY_CHANGE_LAST_WRITE: int
FILE_NOTIFY_CHANGE_SECURITY: int
FILE_CASE_SENSITIVE_SEARCH: int
FILE_CASE_PRESERVED_NAMES: int
FILE_UNICODE_ON_DISK: int
FILE_PERSISTENT_ACLS: int
FILE_FILE_COMPRESSION: int
FILE_VOLUME_IS_COMPRESSED: int
IO_COMPLETION_MODIFY_STATE: int
DUPLICATE_CLOSE_SOURCE: int
DUPLICATE_SAME_ACCESS: int
SID_MAX_SUB_AUTHORITIES: int
SECURITY_NULL_RID: int
SECURITY_WORLD_RID: int
SECURITY_LOCAL_RID: int
SECURITY_CREATOR_OWNER_RID: int
SECURITY_CREATOR_GROUP_RID: int
SECURITY_DIALUP_RID: int
SECURITY_NETWORK_RID: int
SECURITY_BATCH_RID: int
SECURITY_INTERACTIVE_RID: int
SECURITY_SERVICE_RID: int
SECURITY_ANONYMOUS_LOGON_RID: int
SECURITY_LOGON_IDS_RID: int
SECURITY_LOGON_IDS_RID_COUNT: int
SECURITY_LOCAL_SYSTEM_RID: int
SECURITY_NT_NON_UNIQUE: int
SECURITY_BUILTIN_DOMAIN_RID: int
DOMAIN_USER_RID_ADMIN: int
DOMAIN_USER_RID_GUEST: int
DOMAIN_GROUP_RID_ADMINS: int
DOMAIN_GROUP_RID_USERS: int
DOMAIN_GROUP_RID_GUESTS: int
DOMAIN_ALIAS_RID_ADMINS: int
DOMAIN_ALIAS_RID_USERS: int
DOMAIN_ALIAS_RID_GUESTS: int
DOMAIN_ALIAS_RID_POWER_USERS: int
DOMAIN_ALIAS_RID_ACCOUNT_OPS: int
DOMAIN_ALIAS_RID_SYSTEM_OPS: int
DOMAIN_ALIAS_RID_PRINT_OPS: int
DOMAIN_ALIAS_RID_BACKUP_OPS: int
DOMAIN_ALIAS_RID_REPLICATOR: int
SE_GROUP_MANDATORY: int
SE_GROUP_ENABLED_BY_DEFAULT: int
SE_GROUP_ENABLED: int
SE_GROUP_OWNER: int
SE_GROUP_LOGON_ID: int
ACL_REVISION: int
ACL_REVISION1: int
ACL_REVISION2: int
ACCESS_ALLOWED_ACE_TYPE: int
ACCESS_DENIED_ACE_TYPE: int
SYSTEM_AUDIT_ACE_TYPE: int
SYSTEM_ALARM_ACE_TYPE: int
OBJECT_INHERIT_ACE: int
CONTAINER_INHERIT_ACE: int
NO_PROPAGATE_INHERIT_ACE: int
INHERIT_ONLY_ACE: int
VALID_INHERIT_FLAGS: int
SUCCESSFUL_ACCESS_ACE_FLAG: int
FAILED_ACCESS_ACE_FLAG: int
SECURITY_DESCRIPTOR_REVISION: int
SECURITY_DESCRIPTOR_REVISION1: int
SECURITY_DESCRIPTOR_MIN_LENGTH: int
SE_OWNER_DEFAULTED: int
SE_GROUP_DEFAULTED: int
SE_DACL_PRESENT: int
SE_DACL_DEFAULTED: int
SE_SACL_PRESENT: int
SE_SACL_DEFAULTED: int
SE_SELF_RELATIVE: int
SE_PRIVILEGE_ENABLED_BY_DEFAULT: int
SE_PRIVILEGE_ENABLED: int
SE_PRIVILEGE_USED_FOR_ACCESS: int
PRIVILEGE_SET_ALL_NECESSARY: int
SE_CREATE_TOKEN_NAME: str
SE_ASSIGNPRIMARYTOKEN_NAME: str
SE_LOCK_MEMORY_NAME: str
SE_INCREASE_QUOTA_NAME: str
SE_UNSOLICITED_INPUT_NAME: str
SE_MACHINE_ACCOUNT_NAME: str
SE_TCB_NAME: str
SE_SECURITY_NAME: str
SE_TAKE_OWNERSHIP_NAME: str
SE_LOAD_DRIVER_NAME: str
SE_SYSTEM_PROFILE_NAME: str
SE_SYSTEMTIME_NAME: str
SE_PROF_SINGLE_PROCESS_NAME: str
SE_INC_BASE_PRIORITY_NAME: str
SE_CREATE_PAGEFILE_NAME: str
SE_CREATE_PERMANENT_NAME: str
SE_BACKUP_NAME: str
SE_RESTORE_NAME: str
SE_SHUTDOWN_NAME: str
SE_DEBUG_NAME: str
SE_AUDIT_NAME: str
SE_SYSTEM_ENVIRONMENT_NAME: str
SE_CHANGE_NOTIFY_NAME: str
SE_REMOTE_SHUTDOWN_NAME: str
TOKEN_ASSIGN_PRIMARY: int
TOKEN_DUPLICATE: int
TOKEN_IMPERSONATE: int
TOKEN_QUERY: int
TOKEN_QUERY_SOURCE: int
TOKEN_ADJUST_PRIVILEGES: int
TOKEN_ADJUST_GROUPS: int
TOKEN_ADJUST_DEFAULT: int
TOKEN_ALL_ACCESS: int
TOKEN_READ: int
TOKEN_WRITE: int
TOKEN_EXECUTE: int
TOKEN_SOURCE_LENGTH: int
KEY_QUERY_VALUE: int
KEY_SET_VALUE: int
KEY_CREATE_SUB_KEY: int
KEY_ENUMERATE_SUB_KEYS: int
KEY_NOTIFY: int
KEY_CREATE_LINK: int
KEY_WOW64_32KEY: int
KEY_WOW64_64KEY: int
KEY_WOW64_RES: int
KEY_READ: int
KEY_WRITE: int
KEY_EXECUTE: int
KEY_ALL_ACCESS: int
REG_NOTIFY_CHANGE_ATTRIBUTES: int
REG_NOTIFY_CHANGE_SECURITY: int
REG_NONE: int
REG_SZ: int
REG_EXPAND_SZ: int
REG_BINARY: int
REG_DWORD: int
REG_DWORD_LITTLE_ENDIAN: int
REG_DWORD_BIG_ENDIAN: int
REG_LINK: int
REG_MULTI_SZ: int
REG_FULL_RESOURCE_DESCRIPTOR: int
REG_QWORD: int
REG_QWORD_LITTLE_ENDIAN: int
NULL: int
HEAP_NO_SERIALIZE: int
HEAP_GROWABLE: int
HEAP_GENERATE_EXCEPTIONS: int
HEAP_ZERO_MEMORY: int
HEAP_REALLOC_IN_PLACE_ONLY: int
HEAP_TAIL_CHECKING_ENABLED: int
HEAP_FREE_CHECKING_ENABLED: int
HEAP_DISABLE_COALESCE_ON_FREE: int
IS_TEXT_UNICODE_ASCII16: int
IS_TEXT_UNICODE_REVERSE_ASCII16: int
IS_TEXT_UNICODE_STATISTICS: int
IS_TEXT_UNICODE_REVERSE_STATISTICS: int
IS_TEXT_UNICODE_CONTROLS: int
IS_TEXT_UNICODE_REVERSE_CONTROLS: int
IS_TEXT_UNICODE_SIGNATURE: int
IS_TEXT_UNICODE_REVERSE_SIGNATURE: int
IS_TEXT_UNICODE_ILLEGAL_CHARS: int
IS_TEXT_UNICODE_ODD_LENGTH: int
IS_TEXT_UNICODE_DBCS_LEADBYTE: int
IS_TEXT_UNICODE_NULL_BYTES: int
IS_TEXT_UNICODE_UNICODE_MASK: int
IS_TEXT_UNICODE_REVERSE_MASK: int
IS_TEXT_UNICODE_NOT_UNICODE_MASK: int
IS_TEXT_UNICODE_NOT_ASCII_MASK: int
COMPRESSION_FORMAT_NONE: int
COMPRESSION_FORMAT_DEFAULT: int
COMPRESSION_FORMAT_LZNT1: int
COMPRESSION_ENGINE_STANDARD: int
COMPRESSION_ENGINE_MAXIMUM: int
MESSAGE_RESOURCE_UNICODE: int
RTL_CRITSECT_TYPE: int
RTL_RESOURCE_TYPE: int
DLL_PROCESS_ATTACH: int
DLL_THREAD_ATTACH: int
DLL_THREAD_DETACH: int
DLL_PROCESS_DETACH: int
EVENTLOG_SEQUENTIAL_READ: int
EVENTLOG_SEEK_READ: int
EVENTLOG_FORWARDS_READ: int
EVENTLOG_BACKWARDS_READ: int
EVENTLOG_SUCCESS: int
EVENTLOG_ERROR_TYPE: int
EVENTLOG_WARNING_TYPE: int
EVENTLOG_INFORMATION_TYPE: int
EVENTLOG_AUDIT_SUCCESS: int
EVENTLOG_AUDIT_FAILURE: int
EVENTLOG_START_PAIRED_EVENT: int
EVENTLOG_END_PAIRED_EVENT: int
EVENTLOG_END_ALL_PAIRED_EVENTS: int
EVENTLOG_PAIRED_EVENT_ACTIVE: int
EVENTLOG_PAIRED_EVENT_INACTIVE: int
OWNER_SECURITY_INFORMATION: int
GROUP_SECURITY_INFORMATION: int
DACL_SECURITY_INFORMATION: int
SACL_SECURITY_INFORMATION: int
IMAGE_SIZEOF_FILE_HEADER: int
IMAGE_FILE_MACHINE_UNKNOWN: int
IMAGE_NUMBEROF_DIRECTORY_ENTRIES: int
IMAGE_SIZEOF_ROM_OPTIONAL_HEADER: int
IMAGE_SIZEOF_STD_OPTIONAL_HEADER: int
IMAGE_SIZEOF_NT_OPTIONAL_HEADER: int
IMAGE_NT_OPTIONAL_HDR_MAGIC: int
IMAGE_ROM_OPTIONAL_HDR_MAGIC: int
IMAGE_SIZEOF_SHORT_NAME: int
IMAGE_SIZEOF_SECTION_HEADER: int
IMAGE_SIZEOF_SYMBOL: int
IMAGE_SYM_CLASS_NULL: int
IMAGE_SYM_CLASS_AUTOMATIC: int
IMAGE_SYM_CLASS_EXTERNAL: int
IMAGE_SYM_CLASS_STATIC: int
IMAGE_SYM_CLASS_REGISTER: int
IMAGE_SYM_CLASS_EXTERNAL_DEF: int
IMAGE_SYM_CLASS_LABEL: int
IMAGE_SYM_CLASS_UNDEFINED_LABEL: int
IMAGE_SYM_CLASS_MEMBER_OF_STRUCT: int
IMAGE_SYM_CLASS_ARGUMENT: int
IMAGE_SYM_CLASS_STRUCT_TAG: int
IMAGE_SYM_CLASS_MEMBER_OF_UNION: int
IMAGE_SYM_CLASS_UNION_TAG: int
IMAGE_SYM_CLASS_TYPE_DEFINITION: int
IMAGE_SYM_CLASS_UNDEFINED_STATIC: int
IMAGE_SYM_CLASS_ENUM_TAG: int
IMAGE_SYM_CLASS_MEMBER_OF_ENUM: int
IMAGE_SYM_CLASS_REGISTER_PARAM: int
IMAGE_SYM_CLASS_BIT_FIELD: int
IMAGE_SYM_CLASS_BLOCK: int
IMAGE_SYM_CLASS_FUNCTION: int
IMAGE_SYM_CLASS_END_OF_STRUCT: int
IMAGE_SYM_CLASS_FILE: int
IMAGE_SYM_CLASS_SECTION: int
IMAGE_SYM_CLASS_WEAK_EXTERNAL: int
N_BTMASK: int
N_TMASK: int
N_TMASK1: int
N_TMASK2: int
N_BTSHFT: int
N_TSHIFT: int
IMAGE_SIZEOF_AUX_SYMBOL: int
IMAGE_COMDAT_SELECT_NODUPLICATES: int
IMAGE_COMDAT_SELECT_ANY: int
IMAGE_COMDAT_SELECT_SAME_SIZE: int
IMAGE_COMDAT_SELECT_EXACT_MATCH: int
IMAGE_COMDAT_SELECT_ASSOCIATIVE: int
IMAGE_WEAK_EXTERN_SEARCH_NOLIBRARY: int
IMAGE_WEAK_EXTERN_SEARCH_LIBRARY: int
IMAGE_WEAK_EXTERN_SEARCH_ALIAS: int
IMAGE_SIZEOF_RELOCATION: int
IMAGE_REL_I386_SECTION: int
IMAGE_REL_I386_SECREL: int
IMAGE_REL_MIPS_REFHALF: int
IMAGE_REL_MIPS_REFWORD: int
IMAGE_REL_MIPS_JMPADDR: int
IMAGE_REL_MIPS_REFHI: int
IMAGE_REL_MIPS_REFLO: int
IMAGE_REL_MIPS_GPREL: int
IMAGE_REL_MIPS_LITERAL: int
IMAGE_REL_MIPS_SECTION: int
IMAGE_REL_MIPS_SECREL: int
IMAGE_REL_MIPS_REFWORDNB: int
IMAGE_REL_MIPS_PAIR: int
IMAGE_REL_ALPHA_ABSOLUTE: int
IMAGE_REL_ALPHA_REFLONG: int
IMAGE_REL_ALPHA_REFQUAD: int
IMAGE_REL_ALPHA_GPREL32: int
IMAGE_REL_ALPHA_LITERAL: int
IMAGE_REL_ALPHA_LITUSE: int
IMAGE_REL_ALPHA_GPDISP: int
IMAGE_REL_ALPHA_BRADDR: int
IMAGE_REL_ALPHA_HINT: int
IMAGE_REL_ALPHA_INLINE_REFLONG: int
IMAGE_REL_ALPHA_REFHI: int
IMAGE_REL_ALPHA_REFLO: int
IMAGE_REL_ALPHA_PAIR: int
IMAGE_REL_ALPHA_MATCH: int
IMAGE_REL_ALPHA_SECTION: int
IMAGE_REL_ALPHA_SECREL: int
IMAGE_REL_ALPHA_REFLONGNB: int
IMAGE_SIZEOF_BASE_RELOCATION: int
IMAGE_REL_BASED_ABSOLUTE: int
IMAGE_REL_BASED_HIGH: int
IMAGE_REL_BASED_LOW: int
IMAGE_REL_BASED_HIGHLOW: int
IMAGE_REL_BASED_HIGHADJ: int
IMAGE_REL_BASED_MIPS_JMPADDR: int
IMAGE_SIZEOF_LINENUMBER: int
IMAGE_ARCHIVE_START_SIZE: int
IMAGE_ARCHIVE_START: str
IMAGE_ARCHIVE_END: str
IMAGE_ARCHIVE_PAD: str
IMAGE_ARCHIVE_LINKER_MEMBER: str
IMAGE_ARCHIVE_LONGNAMES_MEMBER: str
IMAGE_SIZEOF_ARCHIVE_MEMBER_HDR: int
IMAGE_ORDINAL_FLAG: int

def IMAGE_SNAP_BY_ORDINAL(Ordinal: int) -> bool: ...
def IMAGE_ORDINAL(Ordinal: int) -> int: ...

IMAGE_RESOURCE_NAME_IS_STRING: int
IMAGE_RESOURCE_DATA_IS_DIRECTORY: int
IMAGE_DEBUG_TYPE_UNKNOWN: int
IMAGE_DEBUG_TYPE_COFF: int
IMAGE_DEBUG_TYPE_CODEVIEW: int
IMAGE_DEBUG_TYPE_FPO: int
IMAGE_DEBUG_TYPE_MISC: int
IMAGE_DEBUG_TYPE_EXCEPTION: int
IMAGE_DEBUG_TYPE_FIXUP: int
IMAGE_DEBUG_TYPE_OMAP_TO_SRC: int
IMAGE_DEBUG_TYPE_OMAP_FROM_SRC: int
FRAME_FPO: int
FRAME_TRAP: int
FRAME_TSS: int
SIZEOF_RFPO_DATA: int
IMAGE_DEBUG_MISC_EXENAME: int
IMAGE_SEPARATE_DEBUG_SIGNATURE: int
NEWFRAME: int
ABORTDOC: int
NEXTBAND: int
SETCOLORTABLE: int
GETCOLORTABLE: int
FLUSHOUTPUT: int
DRAFTMODE: int
QUERYESCSUPPORT: int
SETABORTPROC: int
STARTDOC: int
ENDDOC: int
GETPHYSPAGESIZE: int
GETPRINTINGOFFSET: int
GETSCALINGFACTOR: int
MFCOMMENT: int
GETPENWIDTH: int
SETCOPYCOUNT: int
SELECTPAPERSOURCE: int
DEVICEDATA: int
PASSTHROUGH: int
GETTECHNOLGY: int
GETTECHNOLOGY: int
SETLINECAP: int
SETLINEJOIN: int
SETMITERLIMIT: int
BANDINFO: int
DRAWPATTERNRECT: int
GETVECTORPENSIZE: int
GETVECTORBRUSHSIZE: int
ENABLEDUPLEX: int
GETSETPAPERBINS: int
GETSETPRINTORIENT: int
ENUMPAPERBINS: int
SETDIBSCALING: int
EPSPRINTING: int
ENUMPAPERMETRICS: int
GETSETPAPERMETRICS: int
POSTSCRIPT_DATA: int
POSTSCRIPT_IGNORE: int
MOUSETRAILS: int
GETDEVICEUNITS: int
GETEXTENDEDTEXTMETRICS: int
GETEXTENTTABLE: int
GETPAIRKERNTABLE: int
GETTRACKKERNTABLE: int
EXTTEXTOUT: int
GETFACENAME: int
DOWNLOADFACE: int
ENABLERELATIVEWIDTHS: int
ENABLEPAIRKERNING: int
SETKERNTRACK: int
SETALLJUSTVALUES: int
SETCHARSET: int
STRETCHBLT: int
GETSETSCREENPARAMS: int
BEGIN_PATH: int
CLIP_TO_PATH: int
END_PATH: int
EXT_DEVICE_CAPS: int
RESTORE_CTM: int
SAVE_CTM: int
SET_ARC_DIRECTION: int
SET_BACKGROUND_COLOR: int
SET_POLY_MODE: int
SET_SCREEN_ANGLE: int
SET_SPREAD: int
TRANSFORM_CTM: int
SET_CLIP_BOX: int
SET_BOUNDS: int
SET_MIRROR_MODE: int
OPENCHANNEL: int
DOWNLOADHEADER: int
CLOSECHANNEL: int
POSTSCRIPT_PASSTHROUGH: int
ENCAPSULATED_POSTSCRIPT: int
SP_NOTREPORTED: int
SP_ERROR: int
SP_APPABORT: int
SP_USERABORT: int
SP_OUTOFDISK: int
SP_OUTOFMEMORY: int
PR_JOBSTATUS: int
OBJ_PEN: int
OBJ_BRUSH: int
OBJ_DC: int
OBJ_METADC: int
OBJ_PAL: int
OBJ_FONT: int
OBJ_BITMAP: int
OBJ_REGION: int
OBJ_METAFILE: int
OBJ_MEMDC: int
OBJ_EXTPEN: int
OBJ_ENHMETADC: int
OBJ_ENHMETAFILE: int
OBJ_COLORSPACE: int
MWT_IDENTITY: int
MWT_LEFTMULTIPLY: int
MWT_RIGHTMULTIPLY: int
MWT_MIN: int
MWT_MAX: int
BI_RGB: int
BI_RLE8: int
BI_RLE4: int
BI_BITFIELDS: int
TMPF_FIXED_PITCH: int
TMPF_VECTOR: int
TMPF_DEVICE: int
TMPF_TRUETYPE: int
NTM_REGULAR: int
NTM_BOLD: int
NTM_ITALIC: int
LF_FACESIZE: int
LF_FULLFACESIZE: int
OUT_DEFAULT_PRECIS: int
OUT_STRING_PRECIS: int
OUT_CHARACTER_PRECIS: int
OUT_STROKE_PRECIS: int
OUT_TT_PRECIS: int
OUT_DEVICE_PRECIS: int
OUT_RASTER_PRECIS: int
OUT_TT_ONLY_PRECIS: int
OUT_OUTLINE_PRECIS: int
CLIP_DEFAULT_PRECIS: int
CLIP_CHARACTER_PRECIS: int
CLIP_STROKE_PRECIS: int
CLIP_MASK: int
CLIP_LH_ANGLES: int
CLIP_TT_ALWAYS: int
CLIP_EMBEDDED: int
DEFAULT_QUALITY: int
DRAFT_QUALITY: int
PROOF_QUALITY: int
NONANTIALIASED_QUALITY: int
ANTIALIASED_QUALITY: int
CLEARTYPE_QUALITY: int
CLEARTYPE_NATURAL_QUALITY: int
DEFAULT_PITCH: int
FIXED_PITCH: int
VARIABLE_PITCH: int
ANSI_CHARSET: int
DEFAULT_CHARSET: int
SYMBOL_CHARSET: int
SHIFTJIS_CHARSET: int
HANGEUL_CHARSET: int
CHINESEBIG5_CHARSET: int
OEM_CHARSET: int
JOHAB_CHARSET: int
HEBREW_CHARSET: int
ARABIC_CHARSET: int
GREEK_CHARSET: int
TURKISH_CHARSET: int
VIETNAMESE_CHARSET: int
THAI_CHARSET: int
EASTEUROPE_CHARSET: int
RUSSIAN_CHARSET: int
MAC_CHARSET: int
BALTIC_CHARSET: int
FF_DONTCARE: int
FF_ROMAN: int
FF_SWISS: int
FF_MODERN: int
FF_SCRIPT: int
FF_DECORATIVE: int
FW_DONTCARE: int
FW_THIN: int
FW_EXTRALIGHT: int
FW_LIGHT: int
FW_NORMAL: int
FW_MEDIUM: int
FW_SEMIBOLD: int
FW_BOLD: int
FW_EXTRABOLD: int
FW_HEAVY: int
FW_ULTRALIGHT: int
FW_REGULAR: int
FW_DEMIBOLD: int
FW_ULTRABOLD: int
FW_BLACK: int
BS_SOLID: int
BS_NULL: int
BS_HOLLOW: int
BS_HATCHED: int
BS_PATTERN: int
BS_INDEXED: int
BS_DIBPATTERN: int
BS_DIBPATTERNPT: int
BS_PATTERN8X8: int
BS_DIBPATTERN8X8: int
HS_HORIZONTAL: int
HS_VERTICAL: int
HS_FDIAGONAL: int
HS_BDIAGONAL: int
HS_CROSS: int
HS_DIAGCROSS: int
HS_FDIAGONAL1: int
HS_BDIAGONAL1: int
HS_SOLID: int
HS_DENSE1: int
HS_DENSE2: int
HS_DENSE3: int
HS_DENSE4: int
HS_DENSE5: int
HS_DENSE6: int
HS_DENSE7: int
HS_DENSE8: int
HS_NOSHADE: int
HS_HALFTONE: int
HS_SOLIDCLR: int
HS_DITHEREDCLR: int
HS_SOLIDTEXTCLR: int
HS_DITHEREDTEXTCLR: int
HS_SOLIDBKCLR: int
HS_DITHEREDBKCLR: int
HS_API_MAX: int
PS_SOLID: int
PS_DASH: int
PS_DOT: int
PS_DASHDOT: int
PS_DASHDOTDOT: int
PS_NULL: int
PS_INSIDEFRAME: int
PS_USERSTYLE: int
PS_ALTERNATE: int
PS_STYLE_MASK: int
PS_ENDCAP_ROUND: int
PS_ENDCAP_SQUARE: int
PS_ENDCAP_FLAT: int
PS_ENDCAP_MASK: int
PS_JOIN_ROUND: int
PS_JOIN_BEVEL: int
PS_JOIN_MITER: int
PS_JOIN_MASK: int
PS_COSMETIC: int
PS_GEOMETRIC: int
PS_TYPE_MASK: int
AD_COUNTERCLOCKWISE: int
AD_CLOCKWISE: int
DRIVERVERSION: int
TECHNOLOGY: int
HORZSIZE: int
VERTSIZE: int
HORZRES: int
VERTRES: int
BITSPIXEL: int
PLANES: int
NUMBRUSHES: int
NUMPENS: int
NUMMARKERS: int
NUMFONTS: int
NUMCOLORS: int
PDEVICESIZE: int
CURVECAPS: int
LINECAPS: int
POLYGONALCAPS: int
TEXTCAPS: int
CLIPCAPS: int
RASTERCAPS: int
ASPECTX: int
ASPECTY: int
ASPECTXY: int
LOGPIXELSX: int
LOGPIXELSY: int
SIZEPALETTE: int
NUMRESERVED: int
COLORRES: int
PHYSICALWIDTH: int
PHYSICALHEIGHT: int
PHYSICALOFFSETX: int
PHYSICALOFFSETY: int
SCALINGFACTORX: int
SCALINGFACTORY: int
VREFRESH: int
DESKTOPVERTRES: int
DESKTOPHORZRES: int
BLTALIGNMENT: int
SHADEBLENDCAPS: int
COLORMGMTCAPS: int
DT_PLOTTER: int
DT_RASDISPLAY: int
DT_RASPRINTER: int
DT_RASCAMERA: int
DT_CHARSTREAM: int
DT_METAFILE: int
DT_DISPFILE: int
CC_NONE: int
CC_CIRCLES: int
CC_PIE: int
CC_CHORD: int
CC_ELLIPSES: int
CC_WIDE: int
CC_STYLED: int
CC_WIDESTYLED: int
CC_INTERIORS: int
CC_ROUNDRECT: int
LC_NONE: int
LC_POLYLINE: int
LC_MARKER: int
LC_POLYMARKER: int
LC_WIDE: int
LC_STYLED: int
LC_WIDESTYLED: int
LC_INTERIORS: int
PC_NONE: int
PC_POLYGON: int
PC_RECTANGLE: int
PC_WINDPOLYGON: int
PC_TRAPEZOID: int
PC_SCANLINE: int
PC_WIDE: int
PC_STYLED: int
PC_WIDESTYLED: int
PC_INTERIORS: int
CP_NONE: int
CP_RECTANGLE: int
CP_REGION: int
TC_OP_CHARACTER: int
TC_OP_STROKE: int
TC_CP_STROKE: int
TC_CR_90: int
TC_CR_ANY: int
TC_SF_X_YINDEP: int
TC_SA_DOUBLE: int
TC_SA_INTEGER: int
TC_SA_CONTIN: int
TC_EA_DOUBLE: int
TC_IA_ABLE: int
TC_UA_ABLE: int
TC_SO_ABLE: int
TC_RA_ABLE: int
TC_VA_ABLE: int
TC_RESERVED: int
TC_SCROLLBLT: int
RC_BITBLT: int
RC_BANDING: int
RC_SCALING: int
RC_BITMAP64: int
RC_GDI20_OUTPUT: int
RC_GDI20_STATE: int
RC_SAVEBITMAP: int
RC_DI_BITMAP: int
RC_PALETTE: int
RC_DIBTODEV: int
RC_BIGFONT: int
RC_STRETCHBLT: int
RC_FLOODFILL: int
RC_STRETCHDIB: int
RC_OP_DX_OUTPUT: int
RC_DEVBITS: int
DIB_RGB_COLORS: int
DIB_PAL_COLORS: int
DIB_PAL_INDICES: int
DIB_PAL_PHYSINDICES: int
DIB_PAL_LOGINDICES: int
SYSPAL_ERROR: int
SYSPAL_STATIC: int
SYSPAL_NOSTATIC: int
CBM_CREATEDIB: int
CBM_INIT: int
FLOODFILLBORDER: int
FLOODFILLSURFACE: int
CCHDEVICENAME: int
CCHFORMNAME: int
DM_SPECVERSION: int
DM_ORIENTATION: int
DM_PAPERSIZE: int
DM_PAPERLENGTH: int
DM_PAPERWIDTH: int
DM_SCALE: int
DM_POSITION: int
DM_NUP: int
DM_DISPLAYORIENTATION: int
DM_COPIES: int
DM_DEFAULTSOURCE: int
DM_PRINTQUALITY: int
DM_COLOR: int
DM_DUPLEX: int
DM_YRESOLUTION: int
DM_TTOPTION: int
DM_COLLATE: int
DM_FORMNAME: int
DM_LOGPIXELS: int
DM_BITSPERPEL: int
DM_PELSWIDTH: int
DM_PELSHEIGHT: int
DM_DISPLAYFLAGS: int
DM_DISPLAYFREQUENCY: int
DM_ICMMETHOD: int
DM_ICMINTENT: int
DM_MEDIATYPE: int
DM_DITHERTYPE: int
DM_PANNINGWIDTH: int
DM_PANNINGHEIGHT: int
DM_DISPLAYFIXEDOUTPUT: int
DMORIENT_PORTRAIT: int
DMORIENT_LANDSCAPE: int
DMDO_DEFAULT: int
DMDO_90: int
DMDO_180: int
DMDO_270: int
DMDFO_DEFAULT: int
DMDFO_STRETCH: int
DMDFO_CENTER: int
DMPAPER_LETTER: int
DMPAPER_LETTERSMALL: int
DMPAPER_TABLOID: int
DMPAPER_LEDGER: int
DMPAPER_LEGAL: int
DMPAPER_STATEMENT: int
DMPAPER_EXECUTIVE: int
DMPAPER_A3: int
DMPAPER_A4: int
DMPAPER_A4SMALL: int
DMPAPER_A5: int
DMPAPER_B4: int
DMPAPER_B5: int
DMPAPER_FOLIO: int
DMPAPER_QUARTO: int
DMPAPER_10X14: int
DMPAPER_11X17: int
DMPAPER_NOTE: int
DMPAPER_ENV_9: int
DMPAPER_ENV_10: int
DMPAPER_ENV_11: int
DMPAPER_ENV_12: int
DMPAPER_ENV_14: int
DMPAPER_CSHEET: int
DMPAPER_DSHEET: int
DMPAPER_ESHEET: int
DMPAPER_ENV_DL: int
DMPAPER_ENV_C5: int
DMPAPER_ENV_C3: int
DMPAPER_ENV_C4: int
DMPAPER_ENV_C6: int
DMPAPER_ENV_C65: int
DMPAPER_ENV_B4: int
DMPAPER_ENV_B5: int
DMPAPER_ENV_B6: int
DMPAPER_ENV_ITALY: int
DMPAPER_ENV_MONARCH: int
DMPAPER_ENV_PERSONAL: int
DMPAPER_FANFOLD_US: int
DMPAPER_FANFOLD_STD_GERMAN: int
DMPAPER_FANFOLD_LGL_GERMAN: int
DMPAPER_ISO_B4: int
DMPAPER_JAPANESE_POSTCARD: int
DMPAPER_9X11: int
DMPAPER_10X11: int
DMPAPER_15X11: int
DMPAPER_ENV_INVITE: int
DMPAPER_RESERVED_48: int
DMPAPER_RESERVED_49: int
DMPAPER_LETTER_EXTRA: int
DMPAPER_LEGAL_EXTRA: int
DMPAPER_TABLOID_EXTRA: int
DMPAPER_A4_EXTRA: int
DMPAPER_LETTER_TRANSVERSE: int
DMPAPER_A4_TRANSVERSE: int
DMPAPER_LETTER_EXTRA_TRANSVERSE: int
DMPAPER_A_PLUS: int
DMPAPER_B_PLUS: int
DMPAPER_LETTER_PLUS: int
DMPAPER_A4_PLUS: int
DMPAPER_A5_TRANSVERSE: int
DMPAPER_B5_TRANSVERSE: int
DMPAPER_A3_EXTRA: int
DMPAPER_A5_EXTRA: int
DMPAPER_B5_EXTRA: int
DMPAPER_A2: int
DMPAPER_A3_TRANSVERSE: int
DMPAPER_A3_EXTRA_TRANSVERSE: int
DMPAPER_DBL_JAPANESE_POSTCARD: int
DMPAPER_A6: int
DMPAPER_JENV_KAKU2: int
DMPAPER_JENV_KAKU3: int
DMPAPER_JENV_CHOU3: int
DMPAPER_JENV_CHOU4: int
DMPAPER_LETTER_ROTATED: int
DMPAPER_A3_ROTATED: int
DMPAPER_A4_ROTATED: int
DMPAPER_A5_ROTATED: int
DMPAPER_B4_JIS_ROTATED: int
DMPAPER_B5_JIS_ROTATED: int
DMPAPER_JAPANESE_POSTCARD_ROTATED: int
DMPAPER_DBL_JAPANESE_POSTCARD_ROTATED: int
DMPAPER_A6_ROTATED: int
DMPAPER_JENV_KAKU2_ROTATED: int
DMPAPER_JENV_KAKU3_ROTATED: int
DMPAPER_JENV_CHOU3_ROTATED: int
DMPAPER_JENV_CHOU4_ROTATED: int
DMPAPER_B6_JIS: int
DMPAPER_B6_JIS_ROTATED: int
DMPAPER_12X11: int
DMPAPER_JENV_YOU4: int
DMPAPER_JENV_YOU4_ROTATED: int
DMPAPER_P16K: int
DMPAPER_P32K: int
DMPAPER_P32KBIG: int
DMPAPER_PENV_1: int
DMPAPER_PENV_2: int
DMPAPER_PENV_3: int
DMPAPER_PENV_4: int
DMPAPER_PENV_5: int
DMPAPER_PENV_6: int
DMPAPER_PENV_7: int
DMPAPER_PENV_8: int
DMPAPER_PENV_9: int
DMPAPER_PENV_10: int
DMPAPER_P16K_ROTATED: int
DMPAPER_P32K_ROTATED: int
DMPAPER_P32KBIG_ROTATED: int
DMPAPER_PENV_1_ROTATED: int
DMPAPER_PENV_2_ROTATED: int
DMPAPER_PENV_3_ROTATED: int
DMPAPER_PENV_4_ROTATED: int
DMPAPER_PENV_5_ROTATED: int
DMPAPER_PENV_6_ROTATED: int
DMPAPER_PENV_7_ROTATED: int
DMPAPER_PENV_8_ROTATED: int
DMPAPER_PENV_9_ROTATED: int
DMPAPER_PENV_10_ROTATED: int
DMPAPER_LAST: int
DMPAPER_USER: int
DMBIN_UPPER: int
DMBIN_ONLYONE: int
DMBIN_LOWER: int
DMBIN_MIDDLE: int
DMBIN_MANUAL: int
DMBIN_ENVELOPE: int
DMBIN_ENVMANUAL: int
DMBIN_AUTO: int
DMBIN_TRACTOR: int
DMBIN_SMALLFMT: int
DMBIN_LARGEFMT: int
DMBIN_LARGECAPACITY: int
DMBIN_CASSETTE: int
DMBIN_FORMSOURCE: int
DMBIN_LAST: int
DMBIN_USER: int
DMRES_DRAFT: int
DMRES_LOW: int
DMRES_MEDIUM: int
DMRES_HIGH: int
DMCOLOR_MONOCHROME: int
DMCOLOR_COLOR: int
DMDUP_SIMPLEX: int
DMDUP_VERTICAL: int
DMDUP_HORIZONTAL: int
DMTT_BITMAP: int
DMTT_DOWNLOAD: int
DMTT_SUBDEV: int
DMTT_DOWNLOAD_OUTLINE: int
DMCOLLATE_FALSE: int
DMCOLLATE_TRUE: int
DM_GRAYSCALE: int
DM_INTERLACED: int
DMICMMETHOD_NONE: int
DMICMMETHOD_SYSTEM: int
DMICMMETHOD_DRIVER: int
DMICMMETHOD_DEVICE: int
DMICMMETHOD_USER: int
DMICM_SATURATE: int
DMICM_CONTRAST: int
DMICM_COLORIMETRIC: int
DMICM_ABS_COLORIMETRIC: int
DMICM_USER: int
DMMEDIA_STANDARD: int
DMMEDIA_TRANSPARENCY: int
DMMEDIA_GLOSSY: int
DMMEDIA_USER: int
DMDITHER_NONE: int
DMDITHER_COARSE: int
DMDITHER_FINE: int
DMDITHER_LINEART: int
DMDITHER_ERRORDIFFUSION: int
DMDITHER_RESERVED6: int
DMDITHER_RESERVED7: int
DMDITHER_RESERVED8: int
DMDITHER_RESERVED9: int
DMDITHER_GRAYSCALE: int
DMDITHER_USER: int
DMNUP_SYSTEM: int
DMNUP_ONEUP: int
FEATURESETTING_NUP: int
FEATURESETTING_OUTPUT: int
FEATURESETTING_PSLEVEL: int
FEATURESETTING_CUSTPAPER: int
FEATURESETTING_MIRROR: int
FEATURESETTING_NEGATIVE: int
FEATURESETTING_PROTOCOL: int
FEATURESETTING_PRIVATE_BEGIN: int
FEATURESETTING_PRIVATE_END: int
RDH_RECTANGLES: int
GGO_METRICS: int
GGO_BITMAP: int
GGO_NATIVE: int
TT_POLYGON_TYPE: int
TT_PRIM_LINE: int
TT_PRIM_QSPLINE: int
TT_AVAILABLE: int
TT_ENABLED: int
DM_UPDATE: int
DM_COPY: int
DM_PROMPT: int
DM_MODIFY: int
DM_IN_BUFFER: int
DM_IN_PROMPT: int
DM_OUT_BUFFER: int
DM_OUT_DEFAULT: int
DISPLAY_DEVICE_ATTACHED_TO_DESKTOP: int
DISPLAY_DEVICE_MULTI_DRIVER: int
DISPLAY_DEVICE_PRIMARY_DEVICE: int
DISPLAY_DEVICE_MIRRORING_DRIVER: int
DISPLAY_DEVICE_VGA_COMPATIBLE: int
DISPLAY_DEVICE_REMOVABLE: int
DISPLAY_DEVICE_MODESPRUNED: int
DISPLAY_DEVICE_REMOTE: int
DISPLAY_DEVICE_DISCONNECT: int
DC_FIELDS: int
DC_PAPERS: int
DC_PAPERSIZE: int
DC_MINEXTENT: int
DC_MAXEXTENT: int
DC_BINS: int
DC_DUPLEX: int
DC_SIZE: int
DC_EXTRA: int
DC_VERSION: int
DC_DRIVER: int
DC_BINNAMES: int
DC_ENUMRESOLUTIONS: int
DC_FILEDEPENDENCIES: int
DC_TRUETYPE: int
DC_PAPERNAMES: int
DC_ORIENTATION: int
DC_COPIES: int
DC_BINADJUST: int
DC_EMF_COMPLIANT: int
DC_DATATYPE_PRODUCED: int
DC_COLLATE: int
DC_MANUFACTURER: int
DC_MODEL: int
DC_PERSONALITY: int
DC_PRINTRATE: int
DC_PRINTRATEUNIT: int
DC_PRINTERMEM: int
DC_MEDIAREADY: int
DC_STAPLE: int
DC_PRINTRATEPPM: int
DC_COLORDEVICE: int
DC_NUP: int
DC_MEDIATYPENAMES: int
DC_MEDIATYPES: int
PRINTRATEUNIT_PPM: int
PRINTRATEUNIT_CPS: int
PRINTRATEUNIT_LPM: int
PRINTRATEUNIT_IPM: int
DCTT_BITMAP: int
DCTT_DOWNLOAD: int
DCTT_SUBDEV: int
DCTT_DOWNLOAD_OUTLINE: int
DCBA_FACEUPNONE: int
DCBA_FACEUPCENTER: int
DCBA_FACEUPLEFT: int
DCBA_FACEUPRIGHT: int
DCBA_FACEDOWNNONE: int
DCBA_FACEDOWNCENTER: int
DCBA_FACEDOWNLEFT: int
DCBA_FACEDOWNRIGHT: int
CA_NEGATIVE: int
CA_LOG_FILTER: int
ILLUMINANT_DEVICE_DEFAULT: int
ILLUMINANT_A: int
ILLUMINANT_B: int
ILLUMINANT_C: int
ILLUMINANT_D50: int
ILLUMINANT_D55: int
ILLUMINANT_D65: int
ILLUMINANT_D75: int
ILLUMINANT_F2: int
ILLUMINANT_MAX_INDEX: int
ILLUMINANT_TUNGSTEN: int
ILLUMINANT_DAYLIGHT: int
ILLUMINANT_FLUORESCENT: int
ILLUMINANT_NTSC: int
FONTMAPPER_MAX: int
ENHMETA_SIGNATURE: int
ENHMETA_STOCK_OBJECT: int
EMR_HEADER: int
EMR_POLYBEZIER: int
EMR_POLYGON: int
EMR_POLYLINE: int
EMR_POLYBEZIERTO: int
EMR_POLYLINETO: int
EMR_POLYPOLYLINE: int
EMR_POLYPOLYGON: int
EMR_SETWINDOWEXTEX: int
EMR_SETWINDOWORGEX: int
EMR_SETVIEWPORTEXTEX: int
EMR_SETVIEWPORTORGEX: int
EMR_SETBRUSHORGEX: int
EMR_EOF: int
EMR_SETPIXELV: int
EMR_SETMAPPERFLAGS: int
EMR_SETMAPMODE: int
EMR_SETBKMODE: int
EMR_SETPOLYFILLMODE: int
EMR_SETROP2: int
EMR_SETSTRETCHBLTMODE: int
EMR_SETTEXTALIGN: int
EMR_SETCOLORADJUSTMENT: int
EMR_SETTEXTCOLOR: int
EMR_SETBKCOLOR: int
EMR_OFFSETCLIPRGN: int
EMR_MOVETOEX: int
EMR_SETMETARGN: int
EMR_EXCLUDECLIPRECT: int
EMR_INTERSECTCLIPRECT: int
EMR_SCALEVIEWPORTEXTEX: int
EMR_SCALEWINDOWEXTEX: int
EMR_SAVEDC: int
EMR_RESTOREDC: int
EMR_SETWORLDTRANSFORM: int
EMR_MODIFYWORLDTRANSFORM: int
EMR_SELECTOBJECT: int
EMR_CREATEPEN: int
EMR_CREATEBRUSHINDIRECT: int
EMR_DELETEOBJECT: int
EMR_ANGLEARC: int
EMR_ELLIPSE: int
EMR_RECTANGLE: int
EMR_ROUNDRECT: int
EMR_ARC: int
EMR_CHORD: int
EMR_PIE: int
EMR_SELECTPALETTE: int
EMR_CREATEPALETTE: int
EMR_SETPALETTEENTRIES: int
EMR_RESIZEPALETTE: int
EMR_REALIZEPALETTE: int
EMR_EXTFLOODFILL: int
EMR_LINETO: int
EMR_ARCTO: int
EMR_POLYDRAW: int
EMR_SETARCDIRECTION: int
EMR_SETMITERLIMIT: int
EMR_BEGINPATH: int
EMR_ENDPATH: int
EMR_CLOSEFIGURE: int
EMR_FILLPATH: int
EMR_STROKEANDFILLPATH: int
EMR_STROKEPATH: int
EMR_FLATTENPATH: int
EMR_WIDENPATH: int
EMR_SELECTCLIPPATH: int
EMR_ABORTPATH: int
EMR_GDICOMMENT: int
EMR_FILLRGN: int
EMR_FRAMERGN: int
EMR_INVERTRGN: int
EMR_PAINTRGN: int
EMR_EXTSELECTCLIPRGN: int
EMR_BITBLT: int
EMR_STRETCHBLT: int
EMR_MASKBLT: int
EMR_PLGBLT: int
EMR_SETDIBITSTODEVICE: int
EMR_STRETCHDIBITS: int
EMR_EXTCREATEFONTINDIRECTW: int
EMR_EXTTEXTOUTA: int
EMR_EXTTEXTOUTW: int
EMR_POLYBEZIER16: int
EMR_POLYGON16: int
EMR_POLYLINE16: int
EMR_POLYBEZIERTO16: int
EMR_POLYLINETO16: int
EMR_POLYPOLYLINE16: int
EMR_POLYPOLYGON16: int
EMR_POLYDRAW16: int
EMR_CREATEMONOBRUSH: int
EMR_CREATEDIBPATTERNBRUSHPT: int
EMR_EXTCREATEPEN: int
EMR_POLYTEXTOUTA: int
EMR_POLYTEXTOUTW: int
EMR_MIN: int
EMR_MAX: int
PANOSE_COUNT: int
PAN_FAMILYTYPE_INDEX: int
PAN_SERIFSTYLE_INDEX: int
PAN_WEIGHT_INDEX: int
PAN_PROPORTION_INDEX: int
PAN_CONTRAST_INDEX: int
PAN_STROKEVARIATION_INDEX: int
PAN_ARMSTYLE_INDEX: int
PAN_LETTERFORM_INDEX: int
PAN_MIDLINE_INDEX: int
PAN_XHEIGHT_INDEX: int
PAN_CULTURE_LATIN: int
PAN_ANY: int
PAN_NO_FIT: int
PAN_FAMILY_TEXT_DISPLAY: int
PAN_FAMILY_SCRIPT: int
PAN_FAMILY_DECORATIVE: int
PAN_FAMILY_PICTORIAL: int
PAN_SERIF_COVE: int
PAN_SERIF_OBTUSE_COVE: int
PAN_SERIF_SQUARE_COVE: int
PAN_SERIF_OBTUSE_SQUARE_COVE: int
PAN_SERIF_SQUARE: int
PAN_SERIF_THIN: int
PAN_SERIF_BONE: int
PAN_SERIF_EXAGGERATED: int
PAN_SERIF_TRIANGLE: int
PAN_SERIF_NORMAL_SANS: int
PAN_SERIF_OBTUSE_SANS: int
PAN_SERIF_PERP_SANS: int
PAN_SERIF_FLARED: int
PAN_SERIF_ROUNDED: int
PAN_WEIGHT_VERY_LIGHT: int
PAN_WEIGHT_LIGHT: int
PAN_WEIGHT_THIN: int
PAN_WEIGHT_BOOK: int
PAN_WEIGHT_MEDIUM: int
PAN_WEIGHT_DEMI: int
PAN_WEIGHT_BOLD: int
PAN_WEIGHT_HEAVY: int
PAN_WEIGHT_BLACK: int
PAN_WEIGHT_NORD: int
PAN_PROP_OLD_STYLE: int
PAN_PROP_MODERN: int
PAN_PROP_EVEN_WIDTH: int
PAN_PROP_EXPANDED: int
PAN_PROP_CONDENSED: int
PAN_PROP_VERY_EXPANDED: int
PAN_PROP_VERY_CONDENSED: int
PAN_PROP_MONOSPACED: int
PAN_CONTRAST_NONE: int
PAN_CONTRAST_VERY_LOW: int
PAN_CONTRAST_LOW: int
PAN_CONTRAST_MEDIUM_LOW: int
PAN_CONTRAST_MEDIUM: int
PAN_CONTRAST_MEDIUM_HIGH: int
PAN_CONTRAST_HIGH: int
PAN_CONTRAST_VERY_HIGH: int
PAN_STROKE_GRADUAL_DIAG: int
PAN_STROKE_GRADUAL_TRAN: int
PAN_STROKE_GRADUAL_VERT: int
PAN_STROKE_GRADUAL_HORZ: int
PAN_STROKE_RAPID_VERT: int
PAN_STROKE_RAPID_HORZ: int
PAN_STROKE_INSTANT_VERT: int
PAN_STRAIGHT_ARMS_HORZ: int
PAN_STRAIGHT_ARMS_WEDGE: int
PAN_STRAIGHT_ARMS_VERT: int
PAN_STRAIGHT_ARMS_SINGLE_SERIF: int
PAN_STRAIGHT_ARMS_DOUBLE_SERIF: int
PAN_BENT_ARMS_HORZ: int
PAN_BENT_ARMS_WEDGE: int
PAN_BENT_ARMS_VERT: int
PAN_BENT_ARMS_SINGLE_SERIF: int
PAN_BENT_ARMS_DOUBLE_SERIF: int
PAN_LETT_NORMAL_CONTACT: int
PAN_LETT_NORMAL_WEIGHTED: int
PAN_LETT_NORMAL_BOXED: int
PAN_LETT_NORMAL_FLATTENED: int
PAN_LETT_NORMAL_ROUNDED: int
PAN_LETT_NORMAL_OFF_CENTER: int
PAN_LETT_NORMAL_SQUARE: int
PAN_LETT_OBLIQUE_CONTACT: int
PAN_LETT_OBLIQUE_WEIGHTED: int
PAN_LETT_OBLIQUE_BOXED: int
PAN_LETT_OBLIQUE_FLATTENED: int
PAN_LETT_OBLIQUE_ROUNDED: int
PAN_LETT_OBLIQUE_OFF_CENTER: int
PAN_LETT_OBLIQUE_SQUARE: int
PAN_MIDLINE_STANDARD_TRIMMED: int
PAN_MIDLINE_STANDARD_POINTED: int
PAN_MIDLINE_STANDARD_SERIFED: int
PAN_MIDLINE_HIGH_TRIMMED: int
PAN_MIDLINE_HIGH_POINTED: int
PAN_MIDLINE_HIGH_SERIFED: int
PAN_MIDLINE_CONSTANT_TRIMMED: int
PAN_MIDLINE_CONSTANT_POINTED: int
PAN_MIDLINE_CONSTANT_SERIFED: int
PAN_MIDLINE_LOW_TRIMMED: int
PAN_MIDLINE_LOW_POINTED: int
PAN_MIDLINE_LOW_SERIFED: int
PAN_XHEIGHT_CONSTANT_SMALL: int
PAN_XHEIGHT_CONSTANT_STD: int
PAN_XHEIGHT_CONSTANT_LARGE: int
PAN_XHEIGHT_DUCKING_SMALL: int
PAN_XHEIGHT_DUCKING_STD: int
PAN_XHEIGHT_DUCKING_LARGE: int
ELF_VENDOR_SIZE: int
ELF_VERSION: int
ELF_CULTURE_LATIN: int
RASTER_FONTTYPE: int
DEVICE_FONTTYPE: int
TRUETYPE_FONTTYPE: int

def PALETTEINDEX(i: int) -> int: ...

PC_RESERVED: int
PC_EXPLICIT: int
PC_NOCOLLAPSE: int

def GetRValue(rgb: int) -> int: ...
def GetGValue(rgb: int) -> int: ...
def GetBValue(rgb: int) -> int: ...

TRANSPARENT: int
OPAQUE: int
BKMODE_LAST: int
GM_COMPATIBLE: int
GM_ADVANCED: int
GM_LAST: int
PT_CLOSEFIGURE: int
PT_LINETO: int
PT_BEZIERTO: int
PT_MOVETO: int
MM_TEXT: int
MM_LOMETRIC: int
MM_HIMETRIC: int
MM_LOENGLISH: int
MM_HIENGLISH: int
MM_TWIPS: int
MM_ISOTROPIC: int
MM_ANISOTROPIC: int
MM_MIN: int
MM_MAX: int
MM_MAX_FIXEDSCALE: int
ABSOLUTE: int
RELATIVE: int
WHITE_BRUSH: int
LTGRAY_BRUSH: int
GRAY_BRUSH: int
DKGRAY_BRUSH: int
BLACK_BRUSH: int
NULL_BRUSH: int
HOLLOW_BRUSH: int
WHITE_PEN: int
BLACK_PEN: int
NULL_PEN: int
OEM_FIXED_FONT: int
ANSI_FIXED_FONT: int
ANSI_VAR_FONT: int
SYSTEM_FONT: int
DEVICE_DEFAULT_FONT: int
DEFAULT_PALETTE: int
SYSTEM_FIXED_FONT: int
STOCK_LAST: int
CLR_INVALID: int
DC_BRUSH: int
DC_PEN: int
STATUS_WAIT_0: int
STATUS_ABANDONED_WAIT_0: int
STATUS_USER_APC: int
STATUS_TIMEOUT: int
STATUS_PENDING: int
STATUS_SEGMENT_NOTIFICATION: int
STATUS_GUARD_PAGE_VIOLATION: int
STATUS_DATATYPE_MISALIGNMENT: int
STATUS_BREAKPOINT: int
STATUS_SINGLE_STEP: int
STATUS_ACCESS_VIOLATION: int
STATUS_IN_PAGE_ERROR: int
STATUS_INVALID_HANDLE: int
STATUS_NO_MEMORY: int
STATUS_ILLEGAL_INSTRUCTION: int
STATUS_NONCONTINUABLE_EXCEPTION: int
STATUS_INVALID_DISPOSITION: int
STATUS_ARRAY_BOUNDS_EXCEEDED: int
STATUS_FLOAT_DENORMAL_OPERAND: int
STATUS_FLOAT_DIVIDE_BY_ZERO: int
STATUS_FLOAT_INEXACT_RESULT: int
STATUS_FLOAT_INVALID_OPERATION: int
STATUS_FLOAT_OVERFLOW: int
STATUS_FLOAT_STACK_CHECK: int
STATUS_FLOAT_UNDERFLOW: int
STATUS_INTEGER_DIVIDE_BY_ZERO: int
STATUS_INTEGER_OVERFLOW: int
STATUS_PRIVILEGED_INSTRUCTION: int
STATUS_STACK_OVERFLOW: int
STATUS_CONTROL_C_EXIT: int
WAIT_FAILED: int
WAIT_OBJECT_0: int
WAIT_ABANDONED: int
WAIT_ABANDONED_0: int
WAIT_TIMEOUT: int
WAIT_IO_COMPLETION: int
STILL_ACTIVE: int
EXCEPTION_ACCESS_VIOLATION: int
EXCEPTION_DATATYPE_MISALIGNMENT: int
EXCEPTION_BREAKPOINT: int
EXCEPTION_SINGLE_STEP: int
EXCEPTION_ARRAY_BOUNDS_EXCEEDED: int
EXCEPTION_FLT_DENORMAL_OPERAND: int
EXCEPTION_FLT_DIVIDE_BY_ZERO: int
EXCEPTION_FLT_INEXACT_RESULT: int
EXCEPTION_FLT_INVALID_OPERATION: int
EXCEPTION_FLT_OVERFLOW: int
EXCEPTION_FLT_STACK_CHECK: int
EXCEPTION_FLT_UNDERFLOW: int
EXCEPTION_INT_DIVIDE_BY_ZERO: int
EXCEPTION_INT_OVERFLOW: int
EXCEPTION_PRIV_INSTRUCTION: int
EXCEPTION_IN_PAGE_ERROR: int
EXCEPTION_ILLEGAL_INSTRUCTION: int
EXCEPTION_NONCONTINUABLE_EXCEPTION: int
EXCEPTION_STACK_OVERFLOW: int
EXCEPTION_INVALID_DISPOSITION: int
EXCEPTION_GUARD_PAGE: int
EXCEPTION_INVALID_HANDLE: int
CONTROL_C_EXIT: int
SPI_GETBEEP: int
SPI_SETBEEP: int
SPI_GETMOUSE: int
SPI_SETMOUSE: int
SPI_GETBORDER: int
SPI_SETBORDER: int
SPI_GETKEYBOARDSPEED: int
SPI_SETKEYBOARDSPEED: int
SPI_LANGDRIVER: int
SPI_ICONHORIZONTALSPACING: int
SPI_GETSCREENSAVETIMEOUT: int
SPI_SETSCREENSAVETIMEOUT: int
SPI_GETSCREENSAVEACTIVE: int
SPI_SETSCREENSAVEACTIVE: int
SPI_GETGRIDGRANULARITY: int
SPI_SETGRIDGRANULARITY: int
SPI_SETDESKWALLPAPER: int
SPI_SETDESKPATTERN: int
SPI_GETKEYBOARDDELAY: int
SPI_SETKEYBOARDDELAY: int
SPI_ICONVERTICALSPACING: int
SPI_GETICONTITLEWRAP: int
SPI_SETICONTITLEWRAP: int
SPI_GETMENUDROPALIGNMENT: int
SPI_SETMENUDROPALIGNMENT: int
SPI_SETDOUBLECLKWIDTH: int
SPI_SETDOUBLECLKHEIGHT: int
SPI_GETICONTITLELOGFONT: int
SPI_SETDOUBLECLICKTIME: int
SPI_SETMOUSEBUTTONSWAP: int
SPI_SETICONTITLELOGFONT: int
SPI_GETFASTTASKSWITCH: int
SPI_SETFASTTASKSWITCH: int
SPI_SETDRAGFULLWINDOWS: int
SPI_GETDRAGFULLWINDOWS: int
SPI_GETNONCLIENTMETRICS: int
SPI_SETNONCLIENTMETRICS: int
SPI_GETMINIMIZEDMETRICS: int
SPI_SETMINIMIZEDMETRICS: int
SPI_GETICONMETRICS: int
SPI_SETICONMETRICS: int
SPI_SETWORKAREA: int
SPI_GETWORKAREA: int
SPI_SETPENWINDOWS: int
SPI_GETFILTERKEYS: int
SPI_SETFILTERKEYS: int
SPI_GETTOGGLEKEYS: int
SPI_SETTOGGLEKEYS: int
SPI_GETMOUSEKEYS: int
SPI_SETMOUSEKEYS: int
SPI_GETSHOWSOUNDS: int
SPI_SETSHOWSOUNDS: int
SPI_GETSTICKYKEYS: int
SPI_SETSTICKYKEYS: int
SPI_GETACCESSTIMEOUT: int
SPI_SETACCESSTIMEOUT: int
SPI_GETSERIALKEYS: int
SPI_SETSERIALKEYS: int
SPI_GETSOUNDSENTRY: int
SPI_SETSOUNDSENTRY: int
SPI_GETHIGHCONTRAST: int
SPI_SETHIGHCONTRAST: int
SPI_GETKEYBOARDPREF: int
SPI_SETKEYBOARDPREF: int
SPI_GETSCREENREADER: int
SPI_SETSCREENREADER: int
SPI_GETANIMATION: int
SPI_SETANIMATION: int
SPI_GETFONTSMOOTHING: int
SPI_SETFONTSMOOTHING: int
SPI_SETDRAGWIDTH: int
SPI_SETDRAGHEIGHT: int
SPI_SETHANDHELD: int
SPI_GETLOWPOWERTIMEOUT: int
SPI_GETPOWEROFFTIMEOUT: int
SPI_SETLOWPOWERTIMEOUT: int
SPI_SETPOWEROFFTIMEOUT: int
SPI_GETLOWPOWERACTIVE: int
SPI_GETPOWEROFFACTIVE: int
SPI_SETLOWPOWERACTIVE: int
SPI_SETPOWEROFFACTIVE: int
SPI_SETCURSORS: int
SPI_SETICONS: int
SPI_GETDEFAULTINPUTLANG: int
SPI_SETDEFAULTINPUTLANG: int
SPI_SETLANGTOGGLE: int
SPI_GETWINDOWSEXTENSION: int
SPI_SETMOUSETRAILS: int
SPI_GETMOUSETRAILS: int
SPI_GETSNAPTODEFBUTTON: int
SPI_SETSNAPTODEFBUTTON: int
SPI_SETSCREENSAVERRUNNING: int
SPI_SCREENSAVERRUNNING: int
SPI_GETMOUSEHOVERWIDTH: int
SPI_SETMOUSEHOVERWIDTH: int
SPI_GETMOUSEHOVERHEIGHT: int
SPI_SETMOUSEHOVERHEIGHT: int
SPI_GETMOUSEHOVERTIME: int
SPI_SETMOUSEHOVERTIME: int
SPI_GETWHEELSCROLLLINES: int
SPI_SETWHEELSCROLLLINES: int
SPI_GETMENUSHOWDELAY: int
SPI_SETMENUSHOWDELAY: int
SPI_GETSHOWIMEUI: int
SPI_SETSHOWIMEUI: int
SPI_GETMOUSESPEED: int
SPI_SETMOUSESPEED: int
SPI_GETSCREENSAVERRUNNING: int
SPI_GETDESKWALLPAPER: int
SPI_GETACTIVEWINDOWTRACKING: int
SPI_SETACTIVEWINDOWTRACKING: int
SPI_GETMENUANIMATION: int
SPI_SETMENUANIMATION: int
SPI_GETCOMBOBOXANIMATION: int
SPI_SETCOMBOBOXANIMATION: int
SPI_GETGRADIENTCAPTIONS: int
SPI_SETGRADIENTCAPTIONS: int
SPI_GETKEYBOARDCUES: int
SPI_SETKEYBOARDCUES: int
SPI_GETMENUUNDERLINES: int
SPI_SETMENUUNDERLINES: int
SPI_GETACTIVEWNDTRKZORDER: int
SPI_SETACTIVEWNDTRKZORDER: int
SPI_GETHOTTRACKING: int
SPI_SETHOTTRACKING: int
SPI_GETMENUFADE: int
SPI_SETMENUFADE: int
SPI_GETSELECTIONFADE: int
SPI_SETSELECTIONFADE: int
SPI_GETTOOLTIPANIMATION: int
SPI_SETTOOLTIPANIMATION: int
SPI_GETTOOLTIPFADE: int
SPI_SETTOOLTIPFADE: int
SPI_GETCURSORSHADOW: int
SPI_SETCURSORSHADOW: int
SPI_GETMOUSESONAR: int
SPI_SETMOUSESONAR: int
SPI_GETMOUSECLICKLOCK: int
SPI_SETMOUSECLICKLOCK: int
SPI_GETMOUSEVANISH: int
SPI_SETMOUSEVANISH: int
SPI_GETFLATMENU: int
SPI_SETFLATMENU: int
SPI_GETDROPSHADOW: int
SPI_SETDROPSHADOW: int
SPI_GETBLOCKSENDINPUTRESETS: int
SPI_SETBLOCKSENDINPUTRESETS: int
SPI_GETUIEFFECTS: int
SPI_SETUIEFFECTS: int
SPI_GETFOREGROUNDLOCKTIMEOUT: int
SPI_SETFOREGROUNDLOCKTIMEOUT: int
SPI_GETACTIVEWNDTRKTIMEOUT: int
SPI_SETACTIVEWNDTRKTIMEOUT: int
SPI_GETFOREGROUNDFLASHCOUNT: int
SPI_SETFOREGROUNDFLASHCOUNT: int
SPI_GETCARETWIDTH: int
SPI_SETCARETWIDTH: int
SPI_GETMOUSECLICKLOCKTIME: int
SPI_SETMOUSECLICKLOCKTIME: int
SPI_GETFONTSMOOTHINGTYPE: int
SPI_SETFONTSMOOTHINGTYPE: int
SPI_GETFONTSMOOTHINGCONTRAST: int
SPI_SETFONTSMOOTHINGCONTRAST: int
SPI_GETFOCUSBORDERWIDTH: int
SPI_SETFOCUSBORDERWIDTH: int
SPI_GETFOCUSBORDERHEIGHT: int
SPI_SETFOCUSBORDERHEIGHT: int
SPI_GETFONTSMOOTHINGORIENTATION: int
SPI_SETFONTSMOOTHINGORIENTATION: int
SPIF_UPDATEINIFILE: int
SPIF_SENDWININICHANGE: int
SPIF_SENDCHANGE: int
FE_FONTSMOOTHINGSTANDARD: int
FE_FONTSMOOTHINGCLEARTYPE: int
FE_FONTSMOOTHINGDOCKING: int
METRICS_USEDEFAULT: int
ARW_BOTTOMLEFT: int
ARW_BOTTOMRIGHT: int
ARW_TOPLEFT: int
ARW_TOPRIGHT: int
ARW_STARTMASK: int
ARW_STARTRIGHT: int
ARW_STARTTOP: int
ARW_LEFT: int
ARW_RIGHT: int
ARW_UP: int
ARW_DOWN: int
ARW_HIDE: int
SERKF_SERIALKEYSON: int
SERKF_AVAILABLE: int
SERKF_INDICATOR: int
HCF_HIGHCONTRASTON: int
HCF_AVAILABLE: int
HCF_HOTKEYACTIVE: int
HCF_CONFIRMHOTKEY: int
HCF_HOTKEYSOUND: int
HCF_INDICATOR: int
HCF_HOTKEYAVAILABLE: int
CDS_UPDATEREGISTRY: int
CDS_TEST: int
CDS_FULLSCREEN: int
CDS_GLOBAL: int
CDS_SET_PRIMARY: int
CDS_RESET: int
CDS_SETRECT: int
CDS_NORESET: int
DISP_CHANGE_SUCCESSFUL: int
DISP_CHANGE_RESTART: int
DISP_CHANGE_FAILED: int
DISP_CHANGE_BADMODE: int
DISP_CHANGE_NOTUPDATED: int
DISP_CHANGE_BADFLAGS: int
DISP_CHANGE_BADPARAM: int
DISP_CHANGE_BADDUALVIEW: int
ENUM_CURRENT_SETTINGS: int
ENUM_REGISTRY_SETTINGS: int
FKF_FILTERKEYSON: int
FKF_AVAILABLE: int
FKF_HOTKEYACTIVE: int
FKF_CONFIRMHOTKEY: int
FKF_HOTKEYSOUND: int
FKF_INDICATOR: int
FKF_CLICKON: int
SKF_STICKYKEYSON: int
SKF_AVAILABLE: int
SKF_HOTKEYACTIVE: int
SKF_CONFIRMHOTKEY: int
SKF_HOTKEYSOUND: int
SKF_INDICATOR: int
SKF_AUDIBLEFEEDBACK: int
SKF_TRISTATE: int
SKF_TWOKEYSOFF: int
SKF_LALTLATCHED: int
SKF_LCTLLATCHED: int
SKF_LSHIFTLATCHED: int
SKF_RALTLATCHED: int
SKF_RCTLLATCHED: int
SKF_RSHIFTLATCHED: int
SKF_LWINLATCHED: int
SKF_RWINLATCHED: int
SKF_LALTLOCKED: int
SKF_LCTLLOCKED: int
SKF_LSHIFTLOCKED: int
SKF_RALTLOCKED: int
SKF_RCTLLOCKED: int
SKF_RSHIFTLOCKED: int
SKF_LWINLOCKED: int
SKF_RWINLOCKED: int
MKF_MOUSEKEYSON: int
MKF_AVAILABLE: int
MKF_HOTKEYACTIVE: int
MKF_CONFIRMHOTKEY: int
MKF_HOTKEYSOUND: int
MKF_INDICATOR: int
MKF_MODIFIERS: int
MKF_REPLACENUMBERS: int
MKF_LEFTBUTTONSEL: int
MKF_RIGHTBUTTONSEL: int
MKF_LEFTBUTTONDOWN: int
MKF_RIGHTBUTTONDOWN: int
MKF_MOUSEMODE: int
ATF_TIMEOUTON: int
ATF_ONOFFFEEDBACK: int
SSGF_NONE: int
SSGF_DISPLAY: int
SSTF_NONE: int
SSTF_CHARS: int
SSTF_BORDER: int
SSTF_DISPLAY: int
SSWF_NONE: int
SSWF_TITLE: int
SSWF_WINDOW: int
SSWF_DISPLAY: int
SSWF_CUSTOM: int
SSF_SOUNDSENTRYON: int
SSF_AVAILABLE: int
SSF_INDICATOR: int
TKF_TOGGLEKEYSON: int
TKF_AVAILABLE: int
TKF_HOTKEYACTIVE: int
TKF_CONFIRMHOTKEY: int
TKF_HOTKEYSOUND: int
TKF_INDICATOR: int
SLE_ERROR: int
SLE_MINORERROR: int
SLE_WARNING: int
MONITOR_DEFAULTTONULL: int
MONITOR_DEFAULTTOPRIMARY: int
MONITOR_DEFAULTTONEAREST: int
MONITORINFOF_PRIMARY: int
CHILDID_SELF: int
INDEXID_OBJECT: int
INDEXID_CONTAINER: int
OBJID_WINDOW: int
OBJID_SYSMENU: int
OBJID_TITLEBAR: int
OBJID_MENU: int
OBJID_CLIENT: int
OBJID_VSCROLL: int
OBJID_HSCROLL: int
OBJID_SIZEGRIP: int
OBJID_CARET: int
OBJID_CURSOR: int
OBJID_ALERT: int
OBJID_SOUND: int
EVENT_MIN: int
EVENT_MAX: int
EVENT_SYSTEM_SOUND: int
EVENT_SYSTEM_ALERT: int
EVENT_SYSTEM_FOREGROUND: int
EVENT_SYSTEM_MENUSTART: int
EVENT_SYSTEM_MENUEND: int
EVENT_SYSTEM_MENUPOPUPSTART: int
EVENT_SYSTEM_MENUPOPUPEND: int
EVENT_SYSTEM_CAPTURESTART: int
EVENT_SYSTEM_CAPTUREEND: int
EVENT_SYSTEM_MOVESIZESTART: int
EVENT_SYSTEM_MOVESIZEEND: int
EVENT_SYSTEM_CONTEXTHELPSTART: int
EVENT_SYSTEM_CONTEXTHELPEND: int
EVENT_SYSTEM_DRAGDROPSTART: int
EVENT_SYSTEM_DRAGDROPEND: int
EVENT_SYSTEM_DIALOGSTART: int
EVENT_SYSTEM_DIALOGEND: int
EVENT_SYSTEM_SCROLLINGSTART: int
EVENT_SYSTEM_SCROLLINGEND: int
EVENT_SYSTEM_SWITCHSTART: int
EVENT_SYSTEM_SWITCHEND: int
EVENT_SYSTEM_MINIMIZESTART: int
EVENT_SYSTEM_MINIMIZEEND: int
EVENT_OBJECT_CREATE: int
EVENT_OBJECT_DESTROY: int
EVENT_OBJECT_SHOW: int
EVENT_OBJECT_HIDE: int
EVENT_OBJECT_REORDER: int
EVENT_OBJECT_FOCUS: int
EVENT_OBJECT_SELECTION: int
EVENT_OBJECT_SELECTIONADD: int
EVENT_OBJECT_SELECTIONREMOVE: int
EVENT_OBJECT_SELECTIONWITHIN: int
EVENT_OBJECT_STATECHANGE: int
EVENT_OBJECT_LOCATIONCHANGE: int
EVENT_OBJECT_NAMECHANGE: int
EVENT_OBJECT_DESCRIPTIONCHANGE: int
EVENT_OBJECT_VALUECHANGE: int
EVENT_OBJECT_PARENTCHANGE: int
EVENT_OBJECT_HELPCHANGE: int
EVENT_OBJECT_DEFACTIONCHANGE: int
EVENT_OBJECT_ACCELERATORCHANGE: int
SOUND_SYSTEM_STARTUP: int
SOUND_SYSTEM_SHUTDOWN: int
SOUND_SYSTEM_BEEP: int
SOUND_SYSTEM_ERROR: int
SOUND_SYSTEM_QUESTION: int
SOUND_SYSTEM_WARNING: int
SOUND_SYSTEM_INFORMATION: int
SOUND_SYSTEM_MAXIMIZE: int
SOUND_SYSTEM_MINIMIZE: int
SOUND_SYSTEM_RESTOREUP: int
SOUND_SYSTEM_RESTOREDOWN: int
SOUND_SYSTEM_APPSTART: int
SOUND_SYSTEM_FAULT: int
SOUND_SYSTEM_APPEND: int
SOUND_SYSTEM_MENUCOMMAND: int
SOUND_SYSTEM_MENUPOPUP: int
CSOUND_SYSTEM: int
ALERT_SYSTEM_INFORMATIONAL: int
ALERT_SYSTEM_WARNING: int
ALERT_SYSTEM_ERROR: int
ALERT_SYSTEM_QUERY: int
ALERT_SYSTEM_CRITICAL: int
CALERT_SYSTEM: int
WINEVENT_OUTOFCONTEXT: int
WINEVENT_SKIPOWNTHREAD: int
WINEVENT_SKIPOWNPROCESS: int
WINEVENT_INCONTEXT: int
GUI_CARETBLINKING: int
GUI_INMOVESIZE: int
GUI_INMENUMODE: int
GUI_SYSTEMMENUMODE: int
GUI_POPUPMENUMODE: int
STATE_SYSTEM_UNAVAILABLE: int
STATE_SYSTEM_SELECTED: int
STATE_SYSTEM_FOCUSED: int
STATE_SYSTEM_PRESSED: int
STATE_SYSTEM_CHECKED: int
STATE_SYSTEM_MIXED: int
STATE_SYSTEM_READONLY: int
STATE_SYSTEM_HOTTRACKED: int
STATE_SYSTEM_DEFAULT: int
STATE_SYSTEM_EXPANDED: int
STATE_SYSTEM_COLLAPSED: int
STATE_SYSTEM_BUSY: int
STATE_SYSTEM_FLOATING: int
STATE_SYSTEM_MARQUEED: int
STATE_SYSTEM_ANIMATED: int
STATE_SYSTEM_INVISIBLE: int
STATE_SYSTEM_OFFSCREEN: int
STATE_SYSTEM_SIZEABLE: int
STATE_SYSTEM_MOVEABLE: int
STATE_SYSTEM_SELFVOICING: int
STATE_SYSTEM_FOCUSABLE: int
STATE_SYSTEM_SELECTABLE: int
STATE_SYSTEM_LINKED: int
STATE_SYSTEM_TRAVERSED: int
STATE_SYSTEM_MULTISELECTABLE: int
STATE_SYSTEM_EXTSELECTABLE: int
STATE_SYSTEM_ALERT_LOW: int
STATE_SYSTEM_ALERT_MEDIUM: int
STATE_SYSTEM_ALERT_HIGH: int
STATE_SYSTEM_VALID: int
CCHILDREN_TITLEBAR: int
CCHILDREN_SCROLLBAR: int
CURSOR_SHOWING: int
WS_ACTIVECAPTION: int
GA_MIC: int
GA_PARENT: int
GA_ROOT: int
GA_ROOTOWNER: int
GA_MAC: int
BF_LEFT: int
BF_TOP: int
BF_RIGHT: int
BF_BOTTOM: int
BF_TOPLEFT: int
BF_TOPRIGHT: int
BF_BOTTOMLEFT: int
BF_BOTTOMRIGHT: int
BF_RECT: int
BF_DIAGONAL: int
BF_DIAGONAL_ENDTOPRIGHT: int
BF_DIAGONAL_ENDTOPLEFT: int
BF_DIAGONAL_ENDBOTTOMLEFT: int
BF_DIAGONAL_ENDBOTTOMRIGHT: int
BF_MIDDLE: int
BF_SOFT: int
BF_ADJUST: int
BF_FLAT: int
BF_MONO: int
DFC_CAPTION: int
DFC_MENU: int
DFC_SCROLL: int
DFC_BUTTON: int
DFC_POPUPMENU: int
DFCS_CAPTIONCLOSE: int
DFCS_CAPTIONMIN: int
DFCS_CAPTIONMAX: int
DFCS_CAPTIONRESTORE: int
DFCS_CAPTIONHELP: int
DFCS_MENUARROW: int
DFCS_MENUCHECK: int
DFCS_MENUBULLET: int
DFCS_MENUARROWRIGHT: int
DFCS_SCROLLUP: int
DFCS_SCROLLDOWN: int
DFCS_SCROLLLEFT: int
DFCS_SCROLLRIGHT: int
DFCS_SCROLLCOMBOBOX: int
DFCS_SCROLLSIZEGRIP: int
DFCS_SCROLLSIZEGRIPRIGHT: int
DFCS_BUTTONCHECK: int
DFCS_BUTTONRADIOIMAGE: int
DFCS_BUTTONRADIOMASK: int
DFCS_BUTTONRADIO: int
DFCS_BUTTON3STATE: int
DFCS_BUTTONPUSH: int
DFCS_INACTIVE: int
DFCS_PUSHED: int
DFCS_CHECKED: int
DFCS_TRANSPARENT: int
DFCS_HOT: int
DFCS_ADJUSTRECT: int
DFCS_FLAT: int
DFCS_MONO: int
DC_ACTIVE: int
DC_SMALLCAP: int
DC_ICON: int
DC_TEXT: int
DC_INBUTTON: int
DC_GRADIENT: int
IDANI_OPEN: int
IDANI_CLOSE: int
IDANI_CAPTION: int
CF_TEXT: int
CF_BITMAP: int
CF_METAFILEPICT: int
CF_SYLK: int
CF_DIF: int
CF_TIFF: int
CF_OEMTEXT: int
CF_DIB: int
CF_PALETTE: int
CF_PENDATA: int
CF_RIFF: int
CF_WAVE: int
CF_UNICODETEXT: int
CF_ENHMETAFILE: int
CF_HDROP: int
CF_LOCALE: int
CF_DIBV5: int
CF_MAX: int
CF_OWNERDISPLAY: int
CF_DSPTEXT: int
CF_DSPBITMAP: int
CF_DSPMETAFILEPICT: int
CF_DSPENHMETAFILE: int
CF_PRIVATEFIRST: int
CF_PRIVATELAST: int
CF_GDIOBJFIRST: int
CF_GDIOBJLAST: int
FVIRTKEY: int
FNOINVERT: int
FSHIFT: int
FCONTROL: int
FALT: int
WPF_SETMINPOSITION: int
WPF_RESTORETOMAXIMIZED: int
ODT_MENU: int
ODT_COMBOBOX: int
ODT_BUTTON: int
ODT_STATIC: int
ODA_DRAWENTIRE: int
ODA_SELECT: int
ODA_FOCUS: int
ODS_SELECTED: int
ODS_GRAYED: int
ODS_DISABLED: int
ODS_CHECKED: int
ODS_FOCUS: int
ODS_DEFAULT: int
ODS_COMBOBOXEDIT: int
ODS_HOTLIGHT: int
ODS_INACTIVE: int
PM_NOREMOVE: int
PM_REMOVE: int
PM_NOYIELD: int
MOD_ALT: int
MOD_CONTROL: int
MOD_SHIFT: int
MOD_WIN: int
IDHOT_SNAPWINDOW: int
IDHOT_SNAPDESKTOP: int
ENDSESSION_LOGOFF: int
EWX_LOGOFF: int
EWX_SHUTDOWN: int
EWX_REBOOT: int
EWX_FORCE: int
EWX_POWEROFF: int
EWX_FORCEIFHUNG: int
BSM_ALLCOMPONENTS: int
BSM_VXDS: int
BSM_NETDRIVER: int
BSM_INSTALLABLEDRIVERS: int
BSM_APPLICATIONS: int
BSM_ALLDESKTOPS: int
BSF_QUERY: int
BSF_IGNORECURRENTTASK: int
BSF_FLUSHDISK: int
BSF_NOHANG: int
BSF_POSTMESSAGE: int
BSF_FORCEIFHUNG: int
BSF_NOTIMEOUTIFNOTHUNG: int
BROADCAST_QUERY_DENY: int
DBWF_LPARAMPOINTER: int
SWP_NOSIZE: int
SWP_NOMOVE: int
SWP_NOZORDER: int
SWP_NOREDRAW: int
SWP_NOACTIVATE: int
SWP_FRAMECHANGED: int
SWP_SHOWWINDOW: int
SWP_HIDEWINDOW: int
SWP_NOCOPYBITS: int
SWP_NOOWNERZORDER: int
SWP_NOSENDCHANGING: int
SWP_DRAWFRAME: int
SWP_NOREPOSITION: int
SWP_DEFERERASE: int
SWP_ASYNCWINDOWPOS: int
DLGWINDOWEXTRA: int
KEYEVENTF_EXTENDEDKEY: int
KEYEVENTF_KEYUP: int
MOUSEEVENTF_MOVE: int
MOUSEEVENTF_LEFTDOWN: int
MOUSEEVENTF_LEFTUP: int
MOUSEEVENTF_RIGHTDOWN: int
MOUSEEVENTF_RIGHTUP: int
MOUSEEVENTF_MIDDLEDOWN: int
MOUSEEVENTF_MIDDLEUP: int
MOUSEEVENTF_ABSOLUTE: int
INPUT_MOUSE: int
INPUT_KEYBOARD: int
INPUT_HARDWARE: int
MWMO_WAITALL: int
MWMO_ALERTABLE: int
MWMO_INPUTAVAILABLE: int
QS_KEY: int
QS_MOUSEMOVE: int
QS_MOUSEBUTTON: int
QS_POSTMESSAGE: int
QS_TIMER: int
QS_PAINT: int
QS_SENDMESSAGE: int
QS_HOTKEY: int
QS_MOUSE: int
QS_INPUT: int
QS_ALLEVENTS: int
QS_ALLINPUT: int
IMN_CLOSESTATUSWINDOW: int
IMN_OPENSTATUSWINDOW: int
IMN_CHANGECANDIDATE: int
IMN_CLOSECANDIDATE: int
IMN_OPENCANDIDATE: int
IMN_SETCONVERSIONMODE: int
IMN_SETSENTENCEMODE: int
IMN_SETOPENSTATUS: int
IMN_SETCANDIDATEPOS: int
IMN_SETCOMPOSITIONFONT: int
IMN_SETCOMPOSITIONWINDOW: int
IMN_SETSTATUSWINDOWPOS: int
IMN_GUIDELINE: int
IMN_PRIVATE: int
HELP_CONTEXT: int
HELP_QUIT: int
HELP_INDEX: int
HELP_CONTENTS: int
HELP_HELPONHELP: int
HELP_SETINDEX: int
HELP_SETCONTENTS: int
HELP_CONTEXTPOPUP: int
HELP_FORCEFILE: int
HELP_KEY: int
HELP_COMMAND: int
HELP_PARTIALKEY: int
HELP_MULTIKEY: int
HELP_SETWINPOS: int
HELP_CONTEXTMENU: int
HELP_FINDER: int
HELP_WM_HELP: int
HELP_SETPOPUP_POS: int
HELP_TCARD: int
HELP_TCARD_DATA: int
HELP_TCARD_OTHER_CALLER: int
IDH_NO_HELP: int
IDH_MISSING_CONTEXT: int
IDH_GENERIC_HELP_BUTTON: int
IDH_OK: int
IDH_CANCEL: int
IDH_HELP: int
GR_GDIOBJECTS: int
GR_USEROBJECTS: int
SRCCOPY: int
SRCPAINT: int
SRCAND: int
SRCINVERT: int
SRCERASE: int
NOTSRCCOPY: int
NOTSRCERASE: int
MERGECOPY: int
MERGEPAINT: int
PATCOPY: int
PATPAINT: int
PATINVERT: int
DSTINVERT: int
BLACKNESS: int
WHITENESS: int
R2_BLACK: int
R2_NOTMERGEPEN: int
R2_MASKNOTPEN: int
R2_NOTCOPYPEN: int
R2_MASKPENNOT: int
R2_NOT: int
R2_XORPEN: int
R2_NOTMASKPEN: int
R2_MASKPEN: int
R2_NOTXORPEN: int
R2_NOP: int
R2_MERGENOTPEN: int
R2_COPYPEN: int
R2_MERGEPENNOT: int
R2_MERGEPEN: int
R2_WHITE: int
R2_LAST: int
GDI_ERROR: int
ERROR: int
NULLREGION: int
SIMPLEREGION: int
COMPLEXREGION: int
RGN_ERROR: int
RGN_AND: int
RGN_OR: int
RGN_XOR: int
RGN_DIFF: int
RGN_COPY: int
RGN_MIN: int
RGN_MAX: int
BLACKONWHITE: int
WHITEONBLACK: int
COLORONCOLOR: int
HALFTONE: int
MAXSTRETCHBLTMODE: int
STRETCH_ANDSCANS: int
STRETCH_ORSCANS: int
STRETCH_DELETESCANS: int
STRETCH_HALFTONE: int
ALTERNATE: int
WINDING: int
POLYFILL_LAST: int
LAYOUT_RTL: int
LAYOUT_BTT: int
LAYOUT_VBH: int
LAYOUT_ORIENTATIONMASK: int
LAYOUT_BITMAPORIENTATIONPRESERVED: int
TA_NOUPDATECP: int
TA_UPDATECP: int
TA_LEFT: int
TA_RIGHT: int
TA_CENTER: int
TA_TOP: int
TA_BOTTOM: int
TA_BASELINE: int
TA_MASK: int
VTA_BASELINE: int
VTA_LEFT: int
VTA_RIGHT: int
VTA_CENTER: int
VTA_BOTTOM: int
VTA_TOP: int
ETO_GRAYED: int
ETO_OPAQUE: int
ETO_CLIPPED: int
ASPECT_FILTERING: int
DCB_RESET: int
DCB_ACCUMULATE: int
DCB_DIRTY: int
DCB_SET: int
DCB_ENABLE: int
DCB_DISABLE: int
META_SETBKCOLOR: int
META_SETBKMODE: int
META_SETMAPMODE: int
META_SETROP2: int
META_SETRELABS: int
META_SETPOLYFILLMODE: int
META_SETSTRETCHBLTMODE: int
META_SETTEXTCHAREXTRA: int
META_SETTEXTCOLOR: int
META_SETTEXTJUSTIFICATION: int
META_SETWINDOWORG: int
META_SETWINDOWEXT: int
META_SETVIEWPORTORG: int
META_SETVIEWPORTEXT: int
META_OFFSETWINDOWORG: int
META_SCALEWINDOWEXT: int
META_OFFSETVIEWPORTORG: int
META_SCALEVIEWPORTEXT: int
META_LINETO: int
META_MOVETO: int
META_EXCLUDECLIPRECT: int
META_INTERSECTCLIPRECT: int
META_ARC: int
META_ELLIPSE: int
META_FLOODFILL: int
META_PIE: int
META_RECTANGLE: int
META_ROUNDRECT: int
META_PATBLT: int
META_SAVEDC: int
META_SETPIXEL: int
META_OFFSETCLIPRGN: int
META_TEXTOUT: int
META_BITBLT: int
META_STRETCHBLT: int
META_POLYGON: int
META_POLYLINE: int
META_ESCAPE: int
META_RESTOREDC: int
META_FILLREGION: int
META_FRAMEREGION: int
META_INVERTREGION: int
META_PAINTREGION: int
META_SELECTCLIPREGION: int
META_SELECTOBJECT: int
META_SETTEXTALIGN: int
META_CHORD: int
META_SETMAPPERFLAGS: int
META_EXTTEXTOUT: int
META_SETDIBTODEV: int
META_SELECTPALETTE: int
META_REALIZEPALETTE: int
META_ANIMATEPALETTE: int
META_SETPALENTRIES: int
META_POLYPOLYGON: int
META_RESIZEPALETTE: int
META_DIBBITBLT: int
META_DIBSTRETCHBLT: int
META_DIBCREATEPATTERNBRUSH: int
META_STRETCHDIB: int
META_EXTFLOODFILL: int
META_DELETEOBJECT: int
META_CREATEPALETTE: int
META_CREATEPATTERNBRUSH: int
META_CREATEPENINDIRECT: int
META_CREATEFONTINDIRECT: int
META_CREATEBRUSHINDIRECT: int
META_CREATEREGION: int
FILE_BEGIN: int
FILE_CURRENT: int
FILE_END: int
FILE_FLAG_WRITE_THROUGH: int
FILE_FLAG_OVERLAPPED: int
FILE_FLAG_NO_BUFFERING: int
FILE_FLAG_RANDOM_ACCESS: int
FILE_FLAG_SEQUENTIAL_SCAN: int
FILE_FLAG_DELETE_ON_CLOSE: int
FILE_FLAG_BACKUP_SEMANTICS: int
FILE_FLAG_POSIX_SEMANTICS: int
CREATE_NEW: int
CREATE_ALWAYS: int
OPEN_EXISTING: int
OPEN_ALWAYS: int
TRUNCATE_EXISTING: int
PIPE_ACCESS_INBOUND: int
PIPE_ACCESS_OUTBOUND: int
PIPE_ACCESS_DUPLEX: int
PIPE_CLIENT_END: int
PIPE_SERVER_END: int
PIPE_WAIT: int
PIPE_NOWAIT: int
PIPE_READMODE_BYTE: int
PIPE_READMODE_MESSAGE: int
PIPE_TYPE_BYTE: int
PIPE_TYPE_MESSAGE: int
PIPE_UNLIMITED_INSTANCES: int
SECURITY_CONTEXT_TRACKING: int
SECURITY_EFFECTIVE_ONLY: int
SECURITY_SQOS_PRESENT: int
SECURITY_VALID_SQOS_FLAGS: int
DTR_CONTROL_DISABLE: int
DTR_CONTROL_ENABLE: int
DTR_CONTROL_HANDSHAKE: int
RTS_CONTROL_DISABLE: int
RTS_CONTROL_ENABLE: int
RTS_CONTROL_HANDSHAKE: int
RTS_CONTROL_TOGGLE: int
GMEM_FIXED: int
GMEM_MOVEABLE: int
GMEM_NOCOMPACT: int
GMEM_NODISCARD: int
GMEM_ZEROINIT: int
GMEM_MODIFY: int
GMEM_DISCARDABLE: int
GMEM_NOT_BANKED: int
GMEM_SHARE: int
GMEM_DDESHARE: int
GMEM_NOTIFY: int
GMEM_LOWER: int
GMEM_VALID_FLAGS: int
GMEM_INVALID_HANDLE: int
GHND: int
GPTR: int
GMEM_DISCARDED: int
GMEM_LOCKCOUNT: int
LMEM_FIXED: int
LMEM_MOVEABLE: int
LMEM_NOCOMPACT: int
LMEM_NODISCARD: int
LMEM_ZEROINIT: int
LMEM_MODIFY: int
LMEM_DISCARDABLE: int
LMEM_VALID_FLAGS: int
LMEM_INVALID_HANDLE: int
LHND: int
LPTR: int
NONZEROLHND: int
NONZEROLPTR: int
LMEM_DISCARDED: int
LMEM_LOCKCOUNT: int
DEBUG_PROCESS: int
DEBUG_ONLY_THIS_PROCESS: int
CREATE_SUSPENDED: int
DETACHED_PROCESS: int
CREATE_NEW_CONSOLE: int
NORMAL_PRIORITY_CLASS: int
IDLE_PRIORITY_CLASS: int
HIGH_PRIORITY_CLASS: int
REALTIME_PRIORITY_CLASS: int
CREATE_NEW_PROCESS_GROUP: int
CREATE_UNICODE_ENVIRONMENT: int
CREATE_SEPARATE_WOW_VDM: int
CREATE_SHARED_WOW_VDM: int
CREATE_DEFAULT_ERROR_MODE: int
CREATE_NO_WINDOW: int
PROFILE_USER: int
PROFILE_KERNEL: int
PROFILE_SERVER: int
THREAD_BASE_PRIORITY_LOWRT: int
THREAD_BASE_PRIORITY_MAX: int
THREAD_BASE_PRIORITY_MIN: int
THREAD_BASE_PRIORITY_IDLE: int
THREAD_PRIORITY_LOWEST: int
THREAD_PRIORITY_BELOW_NORMAL: int
THREAD_PRIORITY_HIGHEST: int
THREAD_PRIORITY_ABOVE_NORMAL: int
THREAD_PRIORITY_ERROR_RETURN: int
THREAD_PRIORITY_TIME_CRITICAL: int
THREAD_PRIORITY_IDLE: int
THREAD_PRIORITY_NORMAL: int
THREAD_MODE_BACKGROUND_BEGIN: int
THREAD_MODE_BACKGROUND_END: int
EXCEPTION_DEBUG_EVENT: int
CREATE_THREAD_DEBUG_EVENT: int
CREATE_PROCESS_DEBUG_EVENT: int
EXIT_THREAD_DEBUG_EVENT: int
EXIT_PROCESS_DEBUG_EVENT: int
LOAD_DLL_DEBUG_EVENT: int
UNLOAD_DLL_DEBUG_EVENT: int
OUTPUT_DEBUG_STRING_EVENT: int
RIP_EVENT: int
DRIVE_UNKNOWN: int
DRIVE_NO_ROOT_DIR: int
DRIVE_REMOVABLE: int
DRIVE_FIXED: int
DRIVE_REMOTE: int
DRIVE_CDROM: int
DRIVE_RAMDISK: int
FILE_TYPE_UNKNOWN: int
FILE_TYPE_DISK: int
FILE_TYPE_CHAR: int
FILE_TYPE_PIPE: int
FILE_TYPE_REMOTE: int
NOPARITY: int
ODDPARITY: int
EVENPARITY: int
MARKPARITY: int
SPACEPARITY: int
ONESTOPBIT: int
ONE5STOPBITS: int
TWOSTOPBITS: int
CBR_110: int
CBR_300: int
CBR_600: int
CBR_1200: int
CBR_2400: int
CBR_4800: int
CBR_9600: int
CBR_14400: int
CBR_19200: int
CBR_38400: int
CBR_56000: int
CBR_57600: int
CBR_115200: int
CBR_128000: int
CBR_256000: int
S_QUEUEEMPTY: int
S_THRESHOLD: int
S_ALLTHRESHOLD: int
S_NORMAL: int
S_LEGATO: int
S_STACCATO: int
NMPWAIT_WAIT_FOREVER: int
NMPWAIT_NOWAIT: int
NMPWAIT_USE_DEFAULT_WAIT: int
OF_READ: int
OF_WRITE: int
OF_READWRITE: int
OF_SHARE_COMPAT: int
OF_SHARE_EXCLUSIVE: int
OF_SHARE_DENY_WRITE: int
OF_SHARE_DENY_READ: int
OF_SHARE_DENY_NONE: int
OF_PARSE: int
OF_DELETE: int
OF_VERIFY: int
OF_CANCEL: int
OF_CREATE: int
OF_PROMPT: int
OF_EXIST: int
OF_REOPEN: int
OFS_MAXPATHNAME: int
MAXINTATOM: int
PROCESS_HEAP_REGION: int
PROCESS_HEAP_UNCOMMITTED_RANGE: int
PROCESS_HEAP_ENTRY_BUSY: int
PROCESS_HEAP_ENTRY_MOVEABLE: int
PROCESS_HEAP_ENTRY_DDESHARE: int
SCS_32BIT_BINARY: int
SCS_DOS_BINARY: int
SCS_WOW_BINARY: int
SCS_PIF_BINARY: int
SCS_POSIX_BINARY: int
SCS_OS216_BINARY: int
SEM_FAILCRITICALERRORS: int
SEM_NOGPFAULTERRORBOX: int
SEM_NOALIGNMENTFAULTEXCEPT: int
SEM_NOOPENFILEERRORBOX: int
LOCKFILE_FAIL_IMMEDIATELY: int
LOCKFILE_EXCLUSIVE_LOCK: int
HANDLE_FLAG_INHERIT: int
HANDLE_FLAG_PROTECT_FROM_CLOSE: int
HINSTANCE_ERROR: int
GET_TAPE_MEDIA_INFORMATION: int
GET_TAPE_DRIVE_INFORMATION: int
SET_TAPE_MEDIA_INFORMATION: int
SET_TAPE_DRIVE_INFORMATION: int
FORMAT_MESSAGE_ALLOCATE_BUFFER: int
FORMAT_MESSAGE_IGNORE_INSERTS: int
FORMAT_MESSAGE_FROM_STRING: int
FORMAT_MESSAGE_FROM_HMODULE: int
FORMAT_MESSAGE_FROM_SYSTEM: int
FORMAT_MESSAGE_ARGUMENT_ARRAY: int
FORMAT_MESSAGE_MAX_WIDTH_MASK: int
BACKUP_INVALID: int
BACKUP_DATA: int
BACKUP_EA_DATA: int
BACKUP_SECURITY_DATA: int
BACKUP_ALTERNATE_DATA: int
BACKUP_LINK: int
BACKUP_PROPERTY_DATA: int
BACKUP_OBJECT_ID: int
BACKUP_REPARSE_DATA: int
BACKUP_SPARSE_BLOCK: int
STREAM_NORMAL_ATTRIBUTE: int
STREAM_MODIFIED_WHEN_READ: int
STREAM_CONTAINS_SECURITY: int
STREAM_CONTAINS_PROPERTIES: int
STARTF_USESHOWWINDOW: int
STARTF_USESIZE: int
STARTF_USEPOSITION: int
STARTF_USECOUNTCHARS: int
STARTF_USEFILLATTRIBUTE: int
STARTF_FORCEONFEEDBACK: int
STARTF_FORCEOFFFEEDBACK: int
STARTF_USESTDHANDLES: int
STARTF_USEHOTKEY: int
SHUTDOWN_NORETRY: int
DONT_RESOLVE_DLL_REFERENCES: int
LOAD_LIBRARY_AS_DATAFILE: int
LOAD_WITH_ALTERED_SEARCH_PATH: int
DDD_RAW_TARGET_PATH: int
DDD_REMOVE_DEFINITION: int
DDD_EXACT_MATCH_ON_REMOVE: int
MOVEFILE_REPLACE_EXISTING: int
MOVEFILE_COPY_ALLOWED: int
MOVEFILE_DELAY_UNTIL_REBOOT: int
MAX_COMPUTERNAME_LENGTH: int
LOGON32_LOGON_INTERACTIVE: int
LOGON32_LOGON_NETWORK: int
LOGON32_LOGON_BATCH: int
LOGON32_LOGON_SERVICE: int
LOGON32_LOGON_UNLOCK: int
LOGON32_LOGON_NETWORK_CLEARTEXT: int
LOGON32_LOGON_NEW_CREDENTIALS: int
LOGON32_PROVIDER_DEFAULT: int
LOGON32_PROVIDER_WINNT35: int
LOGON32_PROVIDER_WINNT40: int
LOGON32_PROVIDER_WINNT50: int
VER_PLATFORM_WIN32s: int
VER_PLATFORM_WIN32_WINDOWS: int
VER_PLATFORM_WIN32_NT: int
TC_NORMAL: int
TC_HARDERR: int
TC_GP_TRAP: int
TC_SIGNAL: int
AC_LINE_OFFLINE: int
AC_LINE_ONLINE: int
AC_LINE_BACKUP_POWER: int
AC_LINE_UNKNOWN: int
BATTERY_FLAG_HIGH: int
BATTERY_FLAG_LOW: int
BATTERY_FLAG_CRITICAL: int
BATTERY_FLAG_CHARGING: int
BATTERY_FLAG_NO_BATTERY: int
BATTERY_FLAG_UNKNOWN: int
BATTERY_PERCENTAGE_UNKNOWN: int
BATTERY_LIFE_UNKNOWN: int
cchTextLimitDefault: int
EN_MSGFILTER: int
EN_REQUESTRESIZE: int
EN_SELCHANGE: int
EN_DROPFILES: int
EN_PROTECTED: int
EN_CORRECTTEXT: int
EN_STOPNOUNDO: int
EN_IMECHANGE: int
EN_SAVECLIPBOARD: int
EN_OLEOPFAILED: int
ENM_NONE: int
ENM_CHANGE: int
ENM_UPDATE: int
ENM_SCROLL: int
ENM_KEYEVENTS: int
ENM_MOUSEEVENTS: int
ENM_REQUESTRESIZE: int
ENM_SELCHANGE: int
ENM_DROPFILES: int
ENM_PROTECTED: int
ENM_CORRECTTEXT: int
ENM_IMECHANGE: int
ES_SAVESEL: int
ES_SUNKEN: int
ES_DISABLENOSCROLL: int
ES_SELECTIONBAR: int
ES_EX_NOCALLOLEINIT: int
ES_VERTICAL: int
ES_NOIME: int
ES_SELFIME: int
ECO_AUTOWORDSELECTION: int
ECO_AUTOVSCROLL: int
ECO_AUTOHSCROLL: int
ECO_NOHIDESEL: int
ECO_READONLY: int
ECO_WANTRETURN: int
ECO_SAVESEL: int
ECO_SELECTIONBAR: int
ECO_VERTICAL: int
ECOOP_SET: int
ECOOP_OR: int
ECOOP_AND: int
ECOOP_XOR: int
WB_CLASSIFY: int
WB_MOVEWORDLEFT: int
WB_MOVEWORDRIGHT: int
WB_LEFTBREAK: int
WB_RIGHTBREAK: int
WB_MOVEWORDPREV: int
WB_MOVEWORDNEXT: int
WB_PREVBREAK: int
WB_NEXTBREAK: int
PC_FOLLOWING: int
PC_LEADING: int
PC_OVERFLOW: int
PC_DELIMITER: int
WBF_WORDWRAP: int
WBF_WORDBREAK: int
WBF_OVERFLOW: int
WBF_LEVEL1: int
WBF_LEVEL2: int
WBF_CUSTOM: int
CFM_BOLD: int
CFM_ITALIC: int
CFM_UNDERLINE: int
CFM_STRIKEOUT: int
CFM_PROTECTED: int
CFM_SIZE: int
CFM_COLOR: int
CFM_FACE: int
CFM_OFFSET: int
CFM_CHARSET: int
CFE_BOLD: int
CFE_ITALIC: int
CFE_UNDERLINE: int
CFE_STRIKEOUT: int
CFE_PROTECTED: int
CFE_AUTOCOLOR: int
yHeightCharPtsMost: int
SCF_SELECTION: int
SCF_WORD: int
SF_TEXT: int
SF_RTF: int
SF_RTFNOOBJS: int
SF_TEXTIZED: int
SFF_SELECTION: int
SFF_PLAINRTF: int
MAX_TAB_STOPS: int
lDefaultTab: int
PFM_STARTINDENT: int
PFM_RIGHTINDENT: int
PFM_OFFSET: int
PFM_ALIGNMENT: int
PFM_TABSTOPS: int
PFM_NUMBERING: int
PFM_OFFSETINDENT: int
PFN_BULLET: int
PFA_LEFT: int
PFA_RIGHT: int
PFA_CENTER: int
SEL_EMPTY: int
SEL_TEXT: int
SEL_OBJECT: int
SEL_MULTICHAR: int
SEL_MULTIOBJECT: int
OLEOP_DOVERB: int
CF_RTF: str
CF_RTFNOOBJS: str
CF_RETEXTOBJ: str
RIGHT_ALT_PRESSED: int
LEFT_ALT_PRESSED: int
RIGHT_CTRL_PRESSED: int
LEFT_CTRL_PRESSED: int
SHIFT_PRESSED: int
NUMLOCK_ON: int
SCROLLLOCK_ON: int
CAPSLOCK_ON: int
ENHANCED_KEY: int
NLS_DBCSCHAR: int
NLS_ALPHANUMERIC: int
NLS_KATAKANA: int
NLS_HIRAGANA: int
NLS_ROMAN: int
NLS_IME_CONVERSION: int
NLS_IME_DISABLE: int
FROM_LEFT_1ST_BUTTON_PRESSED: int
RIGHTMOST_BUTTON_PRESSED: int
FROM_LEFT_2ND_BUTTON_PRESSED: int
FROM_LEFT_3RD_BUTTON_PRESSED: int
FROM_LEFT_4TH_BUTTON_PRESSED: int
CTRL_C_EVENT: int
CTRL_BREAK_EVENT: int
CTRL_CLOSE_EVENT: int
CTRL_LOGOFF_EVENT: int
CTRL_SHUTDOWN_EVENT: int
MOUSE_MOVED: int
DOUBLE_CLICK: int
MOUSE_WHEELED: int
PSM_SETCURSEL: int
PSM_REMOVEPAGE: int
PSM_ADDPAGE: int
PSM_CHANGED: int
PSM_RESTARTWINDOWS: int
PSM_REBOOTSYSTEM: int
PSM_CANCELTOCLOSE: int
PSM_QUERYSIBLINGS: int
PSM_UNCHANGED: int
PSM_APPLY: int
PSM_SETTITLEA: int
PSM_SETTITLEW: int
PSM_SETWIZBUTTONS: int
PSM_PRESSBUTTON: int
PSM_SETCURSELID: int
PSM_SETFINISHTEXTA: int
PSM_SETFINISHTEXTW: int
PSM_GETTABCONTROL: int
PSM_ISDIALOGMESSAGE: int
PSM_GETCURRENTPAGEHWND: int
PSM_INSERTPAGE: int
PSM_SETHEADERTITLEA: int
PSM_SETHEADERTITLEW: int
PSM_SETHEADERSUBTITLEA: int
PSM_SETHEADERSUBTITLEW: int
PSM_HWNDTOINDEX: int
PSM_INDEXTOHWND: int
PSM_PAGETOINDEX: int
PSM_INDEXTOPAGE: int
PSM_IDTOINDEX: int
PSM_INDEXTOID: int
PSM_GETRESULT: int
PSM_RECALCPAGESIZES: int
NameUnknown: int
NameFullyQualifiedDN: int
NameSamCompatible: int
NameDisplay: int
NameUniqueId: int
NameCanonical: int
NameUserPrincipal: int
NameCanonicalEx: int
NameServicePrincipal: int
NameDnsDomain: int
ComputerNameNetBIOS: int
ComputerNameDnsHostname: int
ComputerNameDnsDomain: int
ComputerNameDnsFullyQualified: int
ComputerNamePhysicalNetBIOS: int
ComputerNamePhysicalDnsHostname: int
ComputerNamePhysicalDnsDomain: int
ComputerNamePhysicalDnsFullyQualified: int
LWA_COLORKEY: int
LWA_ALPHA: int
ULW_COLORKEY: int
ULW_ALPHA: int
ULW_OPAQUE: int
TRUE: int
FALSE: int
MAX_PATH: int
AC_SRC_OVER: int
AC_SRC_ALPHA: int
GRADIENT_FILL_RECT_H: int
GRADIENT_FILL_RECT_V: int
GRADIENT_FILL_TRIANGLE: int
GRADIENT_FILL_OP_FLAG: int
MM_WORKING_SET_MAX_HARD_ENABLE: int
MM_WORKING_SET_MAX_HARD_DISABLE: int
MM_WORKING_SET_MIN_HARD_ENABLE: int
MM_WORKING_SET_MIN_HARD_DISABLE: int
VOLUME_NAME_DOS: int
VOLUME_NAME_GUID: int
VOLUME_NAME_NT: int
VOLUME_NAME_NONE: int
FILE_NAME_NORMALIZED: int
FILE_NAME_OPENED: int
DEVICE_NOTIFY_WINDOW_HANDLE: int
DEVICE_NOTIFY_SERVICE_HANDLE: int
BSF_MSGSRV32ISOK: int
BSF_MSGSRV32ISOK_BIT: int
DBT_APPYEND: int
DBT_DEVNODES_CHANGED: int
DBT_QUERYCHANGECONFIG: int
DBT_CONFIGCHANGED: int
DBT_CONFIGCHANGECANCELED: int
DBT_MONITORCHANGE: int
DBT_SHELLLOGGEDON: int
DBT_CONFIGMGAPI32: int
DBT_VXDINITCOMPLETE: int
DBT_VOLLOCKQUERYLOCK: int
DBT_VOLLOCKLOCKTAKEN: int
DBT_VOLLOCKLOCKFAILED: int
DBT_VOLLOCKQUERYUNLOCK: int
DBT_VOLLOCKLOCKRELEASED: int
DBT_VOLLOCKUNLOCKFAILED: int
LOCKP_ALLOW_WRITES: int
LOCKP_FAIL_WRITES: int
LOCKP_FAIL_MEM_MAPPING: int
LOCKP_ALLOW_MEM_MAPPING: int
LOCKP_USER_MASK: int
LOCKP_LOCK_FOR_FORMAT: int
LOCKF_LOGICAL_LOCK: int
LOCKF_PHYSICAL_LOCK: int
DBT_NO_DISK_SPACE: int
DBT_LOW_DISK_SPACE: int
DBT_CONFIGMGPRIVATE: int
DBT_DEVICEARRIVAL: int
DBT_DEVICEQUERYREMOVE: int
DBT_DEVICEQUERYREMOVEFAILED: int
DBT_DEVICEREMOVEPENDING: int
DBT_DEVICEREMOVECOMPLETE: int
DBT_DEVICETYPESPECIFIC: int
DBT_CUSTOMEVENT: int
DBT_DEVTYP_OEM: int
DBT_DEVTYP_DEVNODE: int
DBT_DEVTYP_VOLUME: int
DBT_DEVTYP_PORT: int
DBT_DEVTYP_NET: int
DBT_DEVTYP_DEVICEINTERFACE: int
DBT_DEVTYP_HANDLE: int
DBTF_MEDIA: int
DBTF_NET: int
DBTF_RESOURCE: int
DBTF_XPORT: int
DBTF_SLOWNET: int
DBT_VPOWERDAPI: int
DBT_USERDEFINED: int
CBS_DROPDOWNLIST: int
CDM_GETFOLDERIDLIST: int
CTLCOLOR_LISTBOX: int
DBT_APPYBEGIN: int
FILE_NAMED_STREAMS: int
FILE_READ_ONLY_VOLUME: int
FILE_SEQUENTIAL_WRITE_ONCE: int
FILE_SUPPORTS_ENCRYPTION: int
FILE_SUPPORTS_EXTENDED_ATTRIBUTES: int
FILE_SUPPORTS_HARD_LINKS: int
FILE_SUPPORTS_OBJECT_IDS: int
FILE_SUPPORTS_OPEN_BY_FILE_ID: int
FILE_SUPPORTS_REPARSE_POINTS: int
FILE_SUPPORTS_SPARSE_FILES: int
FILE_SUPPORTS_TRANSACTIONS: int
FILE_SUPPORTS_USN_JOURNAL: int
FILE_VOLUME_QUOTAS: int
KEYEVENTF_SCANCODE: int
KEYEVENTF_UNICODE: int
MOUSEEVENTF_HWHEEL: int
MOUSEEVENTF_MOVE_NOCOALESCE: int
MOUSEEVENTF_VIRTUALDESK: int
ODT_LISTBOX: int
REG_RESOURCE_LIST: int
REG_RESOURCE_REQUIREMENTS_LIST: int
SC_TASKLIST: int
SPI_GETLISTBOXSMOOTHSCROLLING: int
SPI_SETLISTBOXSMOOTHSCROLLING: int
WM_CTLCOLORLISTBOX: int
